@@ -37,7 +37,7 @@
 
 #include "lss/print_data.h"
 #include "lss/nc_cluster_abundance.h"
-#include "lss/nc_data_cluster_abundance.h"
+#include "nc_data_cluster_ncount.h"
 
 /**
  * nc_mass_funtion_print:
@@ -50,10 +50,10 @@
  *
  */
 void
-nc_mass_function_print (NcData *ca_unbinned, NcHICosmo *model, FILE *out, gchar *header)
+nc_mass_function_print (NcmData *data, NcHICosmo *model, FILE *out, gchar *header)
 {
-  //NcDataNcusterAbundance *dca = (NcDataNcusterAbundance *) NC_DATA_DATA (ca_unbinned);
-  NcClusterAbundance *cad = NC_CLUSTER_ABUNDANCE (NC_DATA_MODEL (ca_unbinned));
+  NcDataClusterNCount *ncount = NC_DATA_CLUSTER_NCOUNT (data);
+  NcClusterAbundance *cad = ncount->cad;
   gint i, j;
   gint nbins_M = 100;
   gint nbins_z = 20;
@@ -62,53 +62,53 @@ nc_mass_function_print (NcData *ca_unbinned, NcHICosmo *model, FILE *out, gchar
 
   for (i = 0; i < nbins_M; i++)
   {
-	gdouble lnM = cad->lnMi + (cad->lnMf - cad->lnMi) / (nbins_M - 1.0) * i;
-	gsl_vector_set (lnM_nodes, i, lnM);
+    gdouble lnM = cad->lnMi + (cad->lnMf - cad->lnMi) / (nbins_M - 1.0) * i;
+    gsl_vector_set (lnM_nodes, i, lnM);
 
-	printf ("lnM = %5.5g Me = %5.5g M10 = %5.5g\n", gsl_vector_get (lnM_nodes, i), exp(gsl_vector_get (lnM_nodes, i)), pow(10, gsl_vector_get (lnM_nodes, i)));
+    printf ("lnM = %5.5g Me = %5.5g M10 = %5.5g\n", gsl_vector_get (lnM_nodes, i), exp(gsl_vector_get (lnM_nodes, i)), pow(10, gsl_vector_get (lnM_nodes, i)));
   }
 
   for (j = 0; j < nbins_z; j++)
   {
-	gdouble z = cad->zi + (cad->zf - cad->zi) / (nbins_z - 1.0) * j;
-	gsl_vector_set (z_nodes, j, z);
+    gdouble z = cad->zi + (cad->zf - cad->zi) / (nbins_z - 1.0) * j;
+    gsl_vector_set (z_nodes, j, z);
 
-	printf ("z = %5.5g\n", gsl_vector_get (z_nodes, j));
+    printf ("z = %5.5g\n", gsl_vector_get (z_nodes, j));
   }
 
   if (header != NULL)
-	fprintf (out, "# %s\n# ", header);
+    fprintf (out, "# %s\n# ", header);
   else
-	fprintf (out, "# ");
+    fprintf (out, "# ");
 
-  gsl_histogram2d * h = nc_data_cluster_abundance_hist_lnM_z (ca_unbinned, lnM_nodes, z_nodes);
+  gsl_histogram2d *h = nc_data_cluster_ncount_hist_lnM_z (data, lnM_nodes, z_nodes);
 
 
   fprintf (out, "# z M N/(logM * V) (catalog) dn/dlog10M (theory) Nmi(catalog)(abundance in bins of redshift and mass) Nmi(theory)\n");
   for (j = 0; j < nbins_z - 1; j++)
   {
-	gdouble zm, dz, zl, zu, V;
-	gsl_histogram2d_get_yrange (h, j, &zl, &zu);
-	zm = (zu + zl) / 2.0;
-	dz = (zu - zl);
-	V = nc_mass_function_dv_dzdomega (cad->mfp, model, zm) * cad->mfp->area_survey * dz;
-	for (i = 0; i < nbins_M; i++)
-	{
-	  gdouble ln_ml, ln_mu, Mm, lnMm, log_mu, log_ml;
-	  gdouble Nmi = gsl_histogram2d_get (h, i, j);
-	  gdouble dndlog10M, ca_M;
-	  gsl_histogram2d_get_xrange (h, i, &ln_ml, &ln_mu);
-	  lnMm = (ln_ml + ln_mu) / 2.0;
-	  Mm = exp (lnMm);
-	  log_mu = log10 (exp(ln_mu));
-	  log_ml = log10 (exp(ln_ml));
-	  dndlog10M = M_LN10 * nc_mass_function_dn_dlnm (cad->mfp, model, lnMm, zm);
-	  ca_M = (log_mu - log_ml) * V * dndlog10M;
+    gdouble zm, dz, zl, zu, V;
+    gsl_histogram2d_get_yrange (h, j, &zl, &zu);
+    zm = (zu + zl) / 2.0;
+    dz = (zu - zl);
+    V = nc_mass_function_dv_dzdomega (cad->mfp, model, zm) * cad->mfp->area_survey * dz;
+    for (i = 0; i < nbins_M; i++)
+    {
+      gdouble ln_ml, ln_mu, Mm, lnMm, log_mu, log_ml;
+      gdouble Nmi = gsl_histogram2d_get (h, i, j);
+      gdouble dndlog10M, ca_M;
+      gsl_histogram2d_get_xrange (h, i, &ln_ml, &ln_mu);
+      lnMm = (ln_ml + ln_mu) / 2.0;
+      Mm = exp (lnMm);
+      log_mu = log10 (exp(ln_mu));
+      log_ml = log10 (exp(ln_ml));
+      dndlog10M = M_LN10 * nc_mass_function_dn_dlnm (cad->mfp, model, lnMm, zm);
+      ca_M = (log_mu - log_ml) * V * dndlog10M;
 
-	  //printf ("log-mu = %5.5g log-ml = %5.5g\n", log_mu, log_ml);
-	  fprintf (out, "% 6.6g % 6.6e % 6.6g % 6.6g % 6.6g % 6.6g\n", zm, Mm, Nmi / ((log_mu - log_ml) * V), dndlog10M, Nmi, ca_M);
-	}
-	fprintf (out, "\n\n");
+      //printf ("log-mu = %5.5g log-ml = %5.5g\n", log_mu, log_ml);
+      fprintf (out, "% 6.6g % 6.6e % 6.6g % 6.6g % 6.6g % 6.6g\n", zm, Mm, Nmi / ((log_mu - log_ml) * V), dndlog10M, Nmi, ca_M);
+    }
+    fprintf (out, "\n\n");
   }
 
   gsl_vector_free (lnM_nodes);
