@@ -28,13 +28,13 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <numcosmo/nc_hicosmo.h>
-#include <numcosmo/data/data.h>
+#include <numcosmo/math/ncm_data.h>
 
 #include <stdio.h>
 
 G_BEGIN_DECLS
 
-void nc_mass_function_print (NcData *ca_unbinned, NcHICosmo *model, FILE *out, gchar *header);
+void nc_mass_function_print (NcmData *ca_unbinned, NcHICosmo *model, FILE *out, gchar *header);
 
 G_END_DECLS
 
