@@ -25,15 +25,16 @@
 /**
  * SECTION:ncm_cfg
  * @title: Library Configuration
- * @short_description: FIXME
+ * @short_description: Library configuration and helper functions
  *
  * FIXME
+ * 
  */
 
 /**
  * SECTION:nc_macros
  * @title: Library Utilities Macros
- * @short_description: FIXME
+ * @short_description: General purpose macros
  *
  * FIXME
  */
@@ -100,6 +101,7 @@
 #include "nc_distance.h"
 #include "nc_recomb.h"
 #include "nc_recomb_seager.h"
+#include "nc_snia_dist_cov.h"
 
 #include <gio/gio.h>
 #ifdef NUMCOSMO_HAVE_FFTW3
@@ -119,9 +121,9 @@ _ncm_cfg_log_message (const gchar *log_domain, GLogLevelFlags log_level, const g
 {
   if (_enable_msg && _log_stream)
   {
-	fprintf (_log_stream, "%s", message);
-	if (_enable_msg_flush)
-	  fflush (_log_stream);
+    fprintf (_log_stream, "%s", message);
+    if (_enable_msg_flush)
+      fflush (_log_stream);
   }
 }
 
@@ -135,11 +137,11 @@ ncm_cfg_init (void)
 {
   const gchar *home;
   if (numcosmo_init)
-	return;
+    return;
   home = g_get_home_dir ();
   numcosmo_path = g_build_filename (home, ".numcosmo", NULL);
   if (!g_file_test (numcosmo_path, G_FILE_TEST_EXISTS))
-	g_mkdir_with_parents (numcosmo_path, 0755);
+    g_mkdir_with_parents (numcosmo_path, 0755);
 
   gsl_err = gsl_set_error_handler_off ();
 #if (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 32)
@@ -227,10 +229,12 @@ ncm_cfg_init (void)
 
   ncm_cfg_register_obj (NC_TYPE_CLUSTER_ABUNDANCE);
 
-	ncm_cfg_register_obj (NC_TYPE_DISTANCE);
+  ncm_cfg_register_obj (NC_TYPE_DISTANCE);
 
-	ncm_cfg_register_obj (NC_TYPE_RECOMB);
-	ncm_cfg_register_obj (NC_TYPE_RECOMB_SEAGER);
+  ncm_cfg_register_obj (NC_TYPE_RECOMB);
+  ncm_cfg_register_obj (NC_TYPE_RECOMB_SEAGER);
+
+  ncm_cfg_register_obj (NC_TYPE_SNIA_DIST_COV);
 
   numcosmo_init = TRUE;
   return;
@@ -275,7 +279,7 @@ ncm_cfg_set_logfile (gchar *filename)
 {
   FILE *out = fopen (filename, "w");
   if (out != NULL)
-	_log_stream = out;
+    _log_stream = out;
   else
     g_error ("ncm_cfg_set_logfile: Can't open logfile (%s)", filename);
 }
@@ -307,7 +311,7 @@ ncm_cfg_logfile_flush (gboolean on) { _enable_msg_flush = on; }
  * FIXME
  */
 void
-nc_message (gchar *msg, ...)
+ncm_message (gchar *msg, ...)
 {
   va_list ap;
   va_start(ap, msg);
@@ -315,6 +319,203 @@ nc_message (gchar *msg, ...)
   va_end (ap);
 }
 
+/**
+ * ncm_string_ww:
+ * @msg: FIXME
+ * @first: FIXME
+ * @rest: FIXME
+ * @ncols: FIXME
+ *
+ * FIXME
+ * 
+ * Returns: (transfer full): word wraped string @msg.
+ */
+gchar *
+ncm_string_ww (const gchar *msg, const gchar *first, const gchar *rest, guint ncols)
+{
+  gchar **msg_split = g_strsplit (msg, " ", 0);
+  guint size_print = strlen (msg_split[0]);
+  guint first_size = strlen (first);
+  guint rest_size = strlen (rest);
+  guint msg_len = strlen (msg);
+  guint msg_final_len = msg_len + first_size + msg_len / ncols * rest_size;
+  GString *msg_ww = g_string_sized_new (msg_final_len);
+  guint i = 1;
+
+  g_string_append_printf (msg_ww, "%s%s", first, msg_split[0]);
+  while (msg_split[i] != NULL)
+  {
+    guint lsize = strlen (msg_split[i]);
+    if (size_print + lsize + 1 > (ncols - first_size))
+      break;
+    g_string_append_printf (msg_ww, " %s", msg_split[i]);
+    size_print += lsize + 1;
+    i++;
+  }
+  g_string_append_printf (msg_ww, "\n");
+
+  while (msg_split[i] != NULL)
+  {
+    size_print = 0;
+    g_string_append_printf (msg_ww, "%s", rest);
+    while (msg_split[i] != NULL)
+    {
+      guint lsize = strlen (msg_split[i]);
+      if (size_print + lsize + 1 > (ncols - rest_size))
+        break;
+      g_string_append_printf (msg_ww, " %s", msg_split[i]);
+      size_print += lsize + 1;
+      i++;
+    }
+    g_string_append_printf (msg_ww, "\n");
+  }
+
+  g_strfreev (msg_split);
+
+  return g_string_free (msg_ww, FALSE);
+}
+
+/**
+ * ncm_message_ww:
+ * @msg: FIXME
+ * @first: FIXME
+ * @rest: FIXME
+ * @ncols: FIXME
+ *
+ * FIXME
+ */
+void 
+ncm_message_ww (const gchar *msg, const gchar *first, const gchar *rest, guint ncols)
+{
+  gchar *msg_ww = ncm_string_ww (msg, first, rest, ncols);
+  g_message ("%s", msg_ww);
+  g_free (msg_ww);
+}
+
+/**
+ * ncm_cfg_msg_sepa:
+ *
+ * Log a message separator.
+ * 
+ */
+void 
+ncm_cfg_msg_sepa (void)
+{
+  g_message ("#----------------------------------------------------------------------------------\n");
+}
+
+static gsl_rng *_rng = NULL;
+
+/**
+ * ncm_cfg_rng_get: (skip)
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
+gsl_rng *
+ncm_cfg_rng_get ()
+{
+  const gsl_rng_type *type;
+  _NCM_STATIC_MUTEX_DECL (create_lock);
+
+  _NCM_MUTEX_LOCK (&create_lock);
+  if (_rng == NULL)
+  {
+    gsl_rng_env_setup();
+    type = gsl_rng_default;
+    _rng = gsl_rng_alloc (type);
+  }
+  _NCM_MUTEX_UNLOCK (&create_lock);
+
+  return _rng;
+}
+
+/**
+ * ncm_cfg_rng_get_state:
+ *
+ * FIXME
+ *
+ * Returns: (transfer full): FIXME
+ */
+gchar *
+ncm_cfg_rng_get_state ()
+{
+  gsl_rng *rng = ncm_cfg_rng_get ();
+  const gchar *name = gsl_rng_name (rng);
+  gpointer state = gsl_rng_state (rng);
+  gsize state_len = gsl_rng_size (rng);
+  GString *state_str = g_string_sized_new (strlen (name) + 2 * state_len + 1);
+  gint i;
+
+  g_string_append_printf (state_str, "%s:", name);
+
+  for (i = 0; i < state_len; i++)
+  {
+    guchar u = ((guchar *)state)[i];
+    g_string_append_printf (state_str, "%02hhX", u);
+  }
+  
+  return g_string_free (state_str, FALSE);
+}
+
+/**
+ * ncm_cfg_rng_set_state:
+ * @state: FIXME
+ *
+ * FIXME
+ *
+ */
+void 
+ncm_cfg_rng_set_state (gchar *state)
+{
+  gchar **name_state = g_strsplit (state, ":", 0);
+  const gsl_rng_type **t, **t0;
+  gsl_rng *rng = ncm_cfg_rng_get ();
+  gboolean found = FALSE;
+
+  t0 = gsl_rng_types_setup ();
+
+  for (t = t0; *t != 0; t++)
+  {
+    if (strcmp ((*t)->name, name_state[0]) == 0)
+    {
+      found = TRUE;
+      break;
+    }
+  }
+  if (!found)
+    g_error ("ncm_cfg_rng_set_state: cannot find algorithm %s\n", name_state[0]);
+
+  if (strcmp (gsl_rng_name (rng), name_state[0]) != 0)
+  {
+    gsl_rng_free (rng);
+    _rng = gsl_rng_alloc (*t);
+    rng = _rng;
+  }
+
+  {
+    gchar byte[3];
+    gpointer state = gsl_rng_state (rng);
+    gsize state_len = gsl_rng_size (rng);
+    gint i;
+    
+    g_assert_cmpuint (state_len, ==, strlen (name_state[1]) / 2);
+
+    for (i = 0; i < state_len; i++)
+    {
+      guchar u;
+      byte[0] = name_state[1][2 * i];
+      byte[1] = name_state[1][2 * i + 1];
+      byte[2] = 0;
+      u = g_ascii_strtoull (byte, NULL, 16);
+      ((guchar *)state)[i] = u;
+    }
+  }
+  
+  g_strfreev (name_state);
+}
+
 /**
  * ncm_cfg_get_fullpath:
  * @filename: FIXME
@@ -358,29 +559,29 @@ ncm_cfg_keyfile_to_arg (GKeyFile *kfile, gchar *group_name, GOptionEntry *entrie
 {
   if (g_key_file_has_group (kfile, group_name))
   {
-	GError *error = NULL;
-	gint i;
-	for (i = 0; entries[i].long_name != NULL; i++)
-	{
-	  if (g_key_file_has_key (kfile, group_name, entries[i].long_name, &error))
-	  {
-		gchar *val = g_key_file_get_value (kfile, group_name, entries[i].long_name, &error);
-		if (entries[i].arg == G_OPTION_ARG_NONE)
-		{
-		  if ((g_ascii_strcasecmp (val, "1") == 0) ||
-		      (g_ascii_strcasecmp (val, "true") == 0))
-		  {
-			argv[argc[0]++] = g_strdup_printf ("--%s", entries[i].long_name);
-		  }
-		  g_free (val);
-		}
-		else if (strlen (val) > 0)
-		{
-		  argv[argc[0]++] = g_strdup_printf ("--%s", entries[i].long_name);
-		  argv[argc[0]++] = val;
-		}
-	  }
-	}
+    GError *error = NULL;
+    gint i;
+    for (i = 0; entries[i].long_name != NULL; i++)
+    {
+      if (g_key_file_has_key (kfile, group_name, entries[i].long_name, &error))
+      {
+        gchar *val = g_key_file_get_value (kfile, group_name, entries[i].long_name, &error);
+        if (entries[i].arg == G_OPTION_ARG_NONE)
+        {
+          if ((g_ascii_strcasecmp (val, "1") == 0) ||
+              (g_ascii_strcasecmp (val, "true") == 0))
+          {
+            argv[argc[0]++] = g_strdup_printf ("--%s", entries[i].long_name);
+          }
+          g_free (val);
+        }
+        else if (strlen (val) > 0)
+        {
+          argv[argc[0]++] = g_strdup_printf ("--%s", entries[i].long_name);
+          argv[argc[0]++] = val;
+        }
+      }
+    }
   }
 }
 
@@ -400,65 +601,69 @@ ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *en
   gint i;
   for (i = 0; entries[i].long_name != NULL; i++)
   {
-	gboolean skip_comment = FALSE;
-	switch (entries[i].arg)
-	{
-	  case G_OPTION_ARG_NONE:
-	  {
-		gboolean arg_b = ((gboolean *)entries[i].arg_data)[0];
-		g_key_file_set_boolean (kfile, group_name, entries[i].long_name, arg_b);
-		break;
-	  }
-	  case G_OPTION_ARG_STRING:
-	  case G_OPTION_ARG_FILENAME:
-	  {
-		gchar **arg_s = (gchar **)entries[i].arg_data;
-		g_key_file_set_string (kfile, group_name, entries[i].long_name, *arg_s != NULL ? *arg_s : "");
-		break;
-	  }
-	  case G_OPTION_ARG_STRING_ARRAY:
-	  case G_OPTION_ARG_FILENAME_ARRAY:
-	  {
-		const gchar ***arg_as = (const gchar ***)entries[i].arg_data;
-		gchar ***arg_cas = (gchar ***)entries[i].arg_data;
-		if (*arg_cas != NULL)
-		  g_key_file_set_string_list (kfile, group_name, entries[i].long_name, *arg_as, g_strv_length (*arg_cas));
-		else
-		  g_key_file_set_string_list (kfile, group_name, entries[i].long_name, NULL, 0);
-		break;
-	  }
-	  case G_OPTION_ARG_INT:
-	  {
-		gint arg_i = ((gint *)entries[i].arg_data)[0];
-		g_key_file_set_integer (kfile, group_name, entries[i].long_name, arg_i);
-		break;
-	  }
-	  case G_OPTION_ARG_INT64:
-	  {
+    gboolean skip_comment = FALSE;
+    switch (entries[i].arg)
+    {
+      case G_OPTION_ARG_NONE:
+      {
+        gboolean arg_b = ((gboolean *)entries[i].arg_data)[0];
+        g_key_file_set_boolean (kfile, group_name, entries[i].long_name, arg_b);
+        break;
+      }
+      case G_OPTION_ARG_STRING:
+      case G_OPTION_ARG_FILENAME:
+      {
+        gchar **arg_s = (gchar **)entries[i].arg_data;
+        g_key_file_set_string (kfile, group_name, entries[i].long_name, *arg_s != NULL ? *arg_s : "");
+        break;
+      }
+      case G_OPTION_ARG_STRING_ARRAY:
+      case G_OPTION_ARG_FILENAME_ARRAY:
+      {
+        const gchar ***arg_as = (const gchar ***)entries[i].arg_data;
+        gchar ***arg_cas = (gchar ***)entries[i].arg_data;
+        if (*arg_cas != NULL)
+          g_key_file_set_string_list (kfile, group_name, entries[i].long_name, *arg_as, g_strv_length (*arg_cas));
+        else
+          g_key_file_set_string_list (kfile, group_name, entries[i].long_name, NULL, 0);
+        break;
+      }
+      case G_OPTION_ARG_INT:
+      {
+        gint arg_i = ((gint *)entries[i].arg_data)[0];
+        g_key_file_set_integer (kfile, group_name, entries[i].long_name, arg_i);
+        break;
+      }
+      case G_OPTION_ARG_INT64:
+      {
 #if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 26))
-		gint64 arg_l = ((gint64 *)entries[i].arg_data)[0];
-		g_key_file_set_int64 (kfile, group_name, entries[i].long_name, arg_l);
+        gint64 arg_l = ((gint64 *)entries[i].arg_data)[0];
+        g_key_file_set_int64 (kfile, group_name, entries[i].long_name, arg_l);
 #else
-		g_error ("ncm_cfg_entries_to_keyfile: gint64 not supported, recompile "PACKAGE_NAME" with glib >= 2.26");
+        g_error ("ncm_cfg_entries_to_keyfile: gint64 not supported, recompile "PACKAGE_NAME" with glib >= 2.26");
 #endif
-		break;
-	  }
-	  case G_OPTION_ARG_DOUBLE:
-	  {
-		gdouble arg_d = ((double *)entries[i].arg_data)[0];
-		g_key_file_set_double (kfile, group_name, entries[i].long_name, arg_d);
-		break;
-	  }
-	  default:
-		skip_comment = TRUE;
-		//g_error ("ncm_cfg_entries_to_keyfile: cannot convert entry type %d to keyfile", entries[i].arg);
-		break;
-	}
-	if (!skip_comment)
-	{
-	  if (!g_key_file_set_comment (kfile, group_name, entries[i].long_name, entries[i].description, &error))
-		g_error ("ncm_cfg_entries_to_keyfile: %s", error->message);
-	}
+        break;
+      }
+      case G_OPTION_ARG_DOUBLE:
+      {
+        gdouble arg_d = ((double *)entries[i].arg_data)[0];
+        g_key_file_set_double (kfile, group_name, entries[i].long_name, arg_d);
+        break;
+      }
+      default:
+        skip_comment = TRUE;
+        //g_error ("ncm_cfg_entries_to_keyfile: cannot convert entry type %d to keyfile", entries[i].arg);
+        break;
+    }
+    if (!skip_comment)
+    {
+      gchar *desc_ww = ncm_string_ww (entries[i].description, "  ", "  ", 80);
+      gchar *desc = g_strdup_printf ("###############################################################################\n\n%s\n", desc_ww);
+      if (!g_key_file_set_comment (kfile, group_name, entries[i].long_name, desc, &error))
+        g_error ("ncm_cfg_entries_to_keyfile: %s", error->message);
+      g_free (desc);
+      g_free (desc_ww);
+    }
   }
 }
 
@@ -475,26 +680,29 @@ ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *en
 const GEnumValue *
 ncm_cfg_get_enum_by_id_name_nick (GType enum_type, const gchar *id_name_nick)
 {
-  GEnumValue *res = NULL;
-  gchar *endptr = NULL;
-  gint64 id = g_ascii_strtoll (id_name_nick, &endptr, 10);
-  GEnumClass *enum_class = NULL;
-
-  g_assert (G_TYPE_IS_ENUM (enum_type));
-
-  enum_class = g_type_class_ref (enum_type);
-  if ((endptr == id_name_nick) || (strlen (endptr) > 0))
+  g_assert (id_name_nick != NULL);
   {
-	res = g_enum_get_value_by_name (enum_class, id_name_nick);
-	if (res == NULL)
-	  res = g_enum_get_value_by_nick (enum_class, id_name_nick);
+    GEnumValue *res = NULL;
+    gchar *endptr = NULL;
+    gint64 id = g_ascii_strtoll (id_name_nick, &endptr, 10);
+    GEnumClass *enum_class = NULL;
+
+    g_assert (G_TYPE_IS_ENUM (enum_type));
+
+    enum_class = g_type_class_ref (enum_type);
+    if ((endptr == id_name_nick) || (strlen (endptr) > 0))
+    {
+      res = g_enum_get_value_by_name (enum_class, id_name_nick);
+      if (res == NULL)
+        res = g_enum_get_value_by_nick (enum_class, id_name_nick);
+    }
+    else
+      res = g_enum_get_value (enum_class, id);
+
+    g_type_class_unref (enum_class);
+
+    return res;
   }
-  else
-	res = g_enum_get_value (enum_class, id);
-
-  g_type_class_unref (enum_class);
-
-  return res;
 }
 
 /**
@@ -521,26 +729,26 @@ ncm_cfg_enum_print_all (GType enum_type, gchar *header)
 
   while ((snia = g_enum_get_value (enum_class, i++)) != NULL)
   {
-	name_max_len = GSL_MAX (name_max_len, strlen (snia->value_name));
-	nick_max_len = GSL_MAX (nick_max_len, strlen (snia->value_nick));
+    name_max_len = GSL_MAX (name_max_len, strlen (snia->value_name));
+    nick_max_len = GSL_MAX (nick_max_len, strlen (snia->value_nick));
   }
 
   printf ("# %s:\n", header);
   pad = 10 + name_max_len + nick_max_len;
   printf ("#");
   while (pad-- != 0)
-	printf ("-");
+    printf ("-");
   printf ("#\n");
   printf ("# Id | %-*s | %-*s |\n", name_max_len, "Name", nick_max_len, "Nick");
   i = 0;
   while ((snia = g_enum_get_value (enum_class, i++)) != NULL)
   {
-	printf ("# %02d | %-*s | %-*s |\n", snia->value, name_max_len, snia->value_name, nick_max_len, snia->value_nick);
+    printf ("# %02d | %-*s | %-*s |\n", snia->value, name_max_len, snia->value_name, nick_max_len, snia->value_nick);
   }
   pad = 10 + name_max_len + nick_max_len;
   printf ("#");
   while (pad-- != 0)
-	printf ("-");
+    printf ("-");
   printf ("#\n");
 
   g_type_class_unref (enum_class);
@@ -574,10 +782,10 @@ ncm_cfg_load_fftw_wisdom (gchar *filename, ...)
 
   if (g_file_test (full_filename, G_FILE_TEST_EXISTS))
   {
-	wis = g_fopen (full_filename, "r");
-	fftw_import_wisdom_from_file(wis);
-	fclose (wis);
-	ret = TRUE;
+    wis = g_fopen (full_filename, "r");
+    fftw_import_wisdom_from_file(wis);
+    fclose (wis);
+    ret = TRUE;
   }
   g_free (file);
   g_free (full_filename);
@@ -727,35 +935,35 @@ ncm_cfg_load_spline (gchar *filename, const gsl_interp_type *stype, NcmSpline **
   FILE *F = ncm_cfg_vfopen (filename, "r", ap);
   va_end (ap);
   if (F == NULL)
-	return FALSE;
+    return FALSE;
 
   if (fread (&size, sizeof (guint64), 1, F) != 1)
-	g_error ("ncm_cfg_save_spline: fwrite error");
+    g_error ("ncm_cfg_save_spline: fwrite error");
 
   if (*s == NULL)
   {
-	xv = ncm_vector_new (size);
-	yv = ncm_vector_new (size);
+    xv = ncm_vector_new (size);
+    yv = ncm_vector_new (size);
   }
   else
   {
-	xv = (*s)->xv;
-	yv = (*s)->yv;
-	g_assert (size == ncm_vector_len(xv));
+    xv = (*s)->xv;
+    yv = (*s)->yv;
+    g_assert (size == ncm_vector_len(xv));
   }
 
   if (fread (ncm_vector_ptr (xv, 0), sizeof (gdouble), size, F) != size)
-	g_error ("ncm_cfg_save_spline: fwrite error");
+    g_error ("ncm_cfg_save_spline: fwrite error");
   if (fread (ncm_vector_ptr (yv, 0), sizeof (gdouble), size, F) != size)
-	g_error ("ncm_cfg_save_spline: fwrite error");
+    g_error ("ncm_cfg_save_spline: fwrite error");
 
   if (*s == NULL)
   {
-	*s = ncm_spline_gsl_new (stype);
-	ncm_spline_set (*s, xv, yv, TRUE);
+    *s = ncm_spline_gsl_new (stype);
+    ncm_spline_set (*s, xv, yv, TRUE);
   }
   else
-	ncm_spline_prepare (*s);
+    ncm_spline_prepare (*s);
 
   fclose (F);
   return TRUE;
@@ -782,17 +990,17 @@ ncm_cfg_save_spline (gchar *filename, NcmSpline *s, ...)
   va_end (ap);
 
   if (F == NULL)
-	return FALSE;
+    return FALSE;
 
   size = s->len;
 
   if (fwrite (&size, sizeof (guint64), 1, F) != 1)
-	g_error ("ncm_cfg_save_spline: fwrite error");
+    g_error ("ncm_cfg_save_spline: fwrite error");
 
   if (fwrite (ncm_vector_ptr (s->xv, 0), sizeof (gdouble), size, F) != size)
-	g_error ("ncm_cfg_save_spline: fwrite error");
+    g_error ("ncm_cfg_save_spline: fwrite error");
   if (fwrite (ncm_vector_ptr (s->yv, 0), sizeof (gdouble), size, F) != size)
-	g_error ("ncm_cfg_save_spline: fwrite error");
+    g_error ("ncm_cfg_save_spline: fwrite error");
 
   fclose (F);
   return TRUE;
@@ -818,7 +1026,7 @@ ncm_cfg_load_vector (gchar *filename, gsl_vector *v, ...)
   va_end (ap);
 
   if (F == NULL)
-	return FALSE;
+    return FALSE;
   gsl_vector_fread (F, v);
   fclose (F);
   return TRUE;
@@ -844,7 +1052,7 @@ ncm_cfg_save_vector (gchar *filename, gsl_vector *v, ...)
   va_end (ap);
 
   if (F == NULL)
-	return FALSE;
+    return FALSE;
   gsl_vector_fwrite (F, v);
   fclose (F);
   return TRUE;
@@ -870,7 +1078,7 @@ ncm_cfg_load_matrix (gchar *filename, gsl_matrix *M, ...)
   va_end (ap);
 
   if (F == NULL)
-	return FALSE;
+    return FALSE;
   gsl_matrix_fread (F, M);
   fclose (F);
   return TRUE;
@@ -896,7 +1104,7 @@ ncm_cfg_save_matrix (gchar *filename, gsl_matrix *M, ...)
   va_end (ap);
 
   if (F == NULL)
-	return FALSE;
+    return FALSE;
   gsl_matrix_fwrite (F, M);
   fclose (F);
   return TRUE;
@@ -1096,16 +1304,16 @@ ncm_cfg_get_default_sqlite3 (void)
   static sqlite3 *db = NULL;
   if (db == NULL)
   {
-	gchar *filename = g_build_filename (PACKAGE_DATA_DIR, NC_CFG_DEFAULT_SQLITE3_FILENAME, NULL);
-	gint ret;
+    gchar *filename = g_build_filename (PACKAGE_DATA_DIR, NC_CFG_DEFAULT_SQLITE3_FILENAME, NULL);
+    gint ret;
 
-	if (!g_file_test (filename, G_FILE_TEST_EXISTS))
-	  g_error ("Default database not found (%s)", filename);
-	ret = sqlite3_open (filename, &db);
-	if (ret  != SQLITE_OK)
-	  g_error ("Connection to database failed: %s", sqlite3_errmsg (db));
+    if (!g_file_test (filename, G_FILE_TEST_EXISTS))
+      g_error ("Default database not found (%s)", filename);
+    ret = sqlite3_open (filename, &db);
+    if (ret  != SQLITE_OK)
+      g_error ("Connection to database failed: %s", sqlite3_errmsg (db));
 
-	g_free (filename);
+    g_free (filename);
   }
 
   return db;
@@ -1131,9 +1339,9 @@ ncm_cfg_command_line (gchar *argv[], gint argc)
 
   for (i = 0; i < argc; i++)
   {
-	tsize += strlen (argv[i]);
-	if (g_strrstr (argv[i], " ") != NULL)
-	  tsize += 2;
+    tsize += strlen (argv[i]);
+    if (g_strrstr (argv[i], " ") != NULL)
+      tsize += 2;
   }
 
   full_cmd_line_ptr = full_cmd_line = g_new (gchar, tsize);
@@ -1144,17 +1352,17 @@ ncm_cfg_command_line (gchar *argv[], gint argc)
 
   for (i = 1; i < argc; i++)
   {
-	gboolean has_space = FALSE;
-	full_cmd_line_ptr[0] = ' ';
-	full_cmd_line_ptr++;
-	argv_size = strlen(argv[i]);
-	has_space = (g_strrstr (argv[i], " ") != NULL);
-	if (has_space)
-	  (full_cmd_line_ptr++)[0] = '\'';
-	memcpy (full_cmd_line_ptr, argv[i], argv_size);
-	full_cmd_line_ptr = &full_cmd_line_ptr[argv_size];
-	if (has_space)
-	  (full_cmd_line_ptr++)[0] = '\'';
+    gboolean has_space = FALSE;
+    full_cmd_line_ptr[0] = ' ';
+    full_cmd_line_ptr++;
+    argv_size = strlen(argv[i]);
+    has_space = (g_strrstr (argv[i], " ") != NULL);
+    if (has_space)
+      (full_cmd_line_ptr++)[0] = '\'';
+    memcpy (full_cmd_line_ptr, argv[i], argv_size);
+    full_cmd_line_ptr = &full_cmd_line_ptr[argv_size];
+    if (has_space)
+      (full_cmd_line_ptr++)[0] = '\'';
   }
 
   full_cmd_line_ptr[0] = '\0';
@@ -1169,7 +1377,7 @@ ncm_cfg_command_line (gchar *argv[], gint argc)
  * Parses the serialized and returns the newly created object.
  *
  * Returns: (transfer full): A new #GObject.
- */
+   */
 GObject *
 ncm_cfg_create_from_string (const gchar *obj_ser)
 #if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
@@ -1183,49 +1391,49 @@ ncm_cfg_create_from_string (const gchar *obj_ser)
 
   if (g_once_init_enter (&regex_init))
   {
-	regex = g_regex_new ("^([A-Z][A-Za-z]*)\\s*(.*?)\\s*$", 0, 0, &error);
-	g_once_init_leave (&regex_init, TRUE);
+    regex = g_regex_new ("^\\s*([A-Z][A-Za-z]*)\\s*(.*?)\\s*$", 0, 0, &error);
+    g_once_init_leave (&regex_init, TRUE);
   }
 
   var_obj = g_variant_parse (G_VARIANT_TYPE ("{sa{sv}}"), obj_ser, NULL, NULL, &error);
   g_clear_error (&error);
   if (var_obj != NULL)
   {
-	GVariant *obj_name = g_variant_get_child_value (var_obj, 0);
-	GVariant *params = g_variant_get_child_value (var_obj, 1);
-	obj = ncm_cfg_create_from_name_params (g_variant_get_string (obj_name, NULL), params);
-	g_variant_unref (obj_name);
-	g_variant_unref (params);
-	g_variant_unref (var_obj);
+    GVariant *obj_name = g_variant_get_child_value (var_obj, 0);
+    GVariant *params = g_variant_get_child_value (var_obj, 1);
+    obj = ncm_cfg_create_from_name_params (g_variant_get_string (obj_name, NULL), params);
+    g_variant_unref (obj_name);
+    g_variant_unref (params);
+    g_variant_unref (var_obj);
   }
   else if (g_regex_match (regex, obj_ser, 0, &match_info))
   {
-	gchar *obj_name = g_match_info_fetch (match_info, 1);
-	gchar *obj_prop = g_match_info_fetch (match_info, 2);
-	GVariant *params = NULL;
+    gchar *obj_name = g_match_info_fetch (match_info, 1);
+    gchar *obj_prop = g_match_info_fetch (match_info, 2);
+    GVariant *params = NULL;
 
-	if (obj_prop != NULL && strlen (obj_prop) > 0)
-	{
-	  params = g_variant_parse (G_VARIANT_TYPE_VARDICT, obj_prop, NULL, NULL, &error);
-	  if (error != NULL)
-	  {
-		g_error ("Cannot parse object '%s' parameters '%s', error %s\n", obj_name, obj_prop, error->message);
-		g_error_free (error);
-	  }
-	}
+    if (obj_prop != NULL && strlen (obj_prop) > 0)
+    {
+      params = g_variant_parse (G_VARIANT_TYPE_VARDICT, obj_prop, NULL, NULL, &error);
+      if (error != NULL)
+      {
+        g_error ("Cannot parse object '%s' parameters '%s', error %s\n", obj_name, obj_prop, error->message);
+        g_error_free (error);
+      }
+    }
 
-	obj = ncm_cfg_create_from_name_params (obj_name, params);
+    obj = ncm_cfg_create_from_name_params (obj_name, params);
 
-	if (params != NULL)
-	  g_variant_unref (params);
-	g_free (obj_name);
-	g_free (obj_prop);
-	g_match_info_free (match_info);
+    if (params != NULL)
+      g_variant_unref (params);
+    g_free (obj_name);
+    g_free (obj_prop);
+    g_match_info_free (match_info);
   }
   else
   {
     g_match_info_free (match_info);
-	g_error ("Cannot indentify object in string '%s'\n", obj_ser);
+    g_error ("Cannot indentify object in string '%s'\n", obj_ser);
   }
 
   return obj;
@@ -1245,7 +1453,7 @@ ncm_cfg_create_from_string (const gchar *obj_ser)
  * FIXME
  *
  * Returns: (transfer full): A new #GObject.
- */
+   */
 GObject *
 ncm_cfg_create_from_name_params (const gchar *obj_name, GVariant *params)
 #if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
@@ -1254,56 +1462,56 @@ ncm_cfg_create_from_name_params (const gchar *obj_name, GVariant *params)
   GType gtype = g_type_from_name (obj_name);
 
   if (gtype == 0)
-	g_error ("Object '%s' is not registered\n", obj_name);
+    g_error ("Object '%s' is not registered\n", obj_name);
 
   g_assert (params == NULL || g_variant_is_of_type (params, G_VARIANT_TYPE ("a{sv}")));
 
   if (params != NULL)
   {
-	GVariantIter *p_iter = g_variant_iter_new (params);
-	gsize nprop = g_variant_iter_n_children (p_iter);
-	GParameter *gprop = g_new (GParameter, nprop);
-	GVariant *var = NULL;
-	guint i = 0;
+    GVariantIter *p_iter = g_variant_iter_new (params);
+    gsize nprop = g_variant_iter_n_children (p_iter);
+    GParameter *gprop = g_new (GParameter, nprop);
+    GVariant *var = NULL;
+    guint i = 0;
 
-	while ((var = g_variant_iter_next_value (p_iter)))
-	{
-	  GVariant *var_key = g_variant_get_child_value (var, 0);
-	  GVariant *var_val = g_variant_get_child_value (var, 1);
-	  GVariant *val = g_variant_get_variant (var_val);
-	  gprop[i].name = g_variant_get_string (var_key, NULL);
+    while ((var = g_variant_iter_next_value (p_iter)))
+    {
+      GVariant *var_key = g_variant_get_child_value (var, 0);
+      GVariant *var_val = g_variant_get_child_value (var, 1);
+      GVariant *val = g_variant_get_variant (var_val);
+      gprop[i].name = g_variant_get_string (var_key, NULL);
 
-	  if (g_variant_is_of_type (val, G_VARIANT_TYPE ("{sa{sv}}")))
-	  {
-		GVariant *nest_obj_key = g_variant_get_child_value (val, 0);
-		GVariant *nest_obj_params = g_variant_get_child_value (val, 1);
-		GValue lval = G_VALUE_INIT;
-		GObject *nest_obj =
-		  ncm_cfg_create_from_name_params (g_variant_get_string (nest_obj_key, NULL),
-		                                   nest_obj_params);
-		g_value_init (&lval, G_TYPE_OBJECT);
-		gprop[i].value = lval;
-		g_value_take_object (&gprop[i].value, nest_obj);
-		g_variant_unref (nest_obj_key);
-		g_variant_unref (nest_obj_params);
-	  }
-	  else
-		g_dbus_gvariant_to_gvalue (val, &gprop[i].value);
+      if (g_variant_is_of_type (val, G_VARIANT_TYPE ("{sa{sv}}")))
+      {
+        GVariant *nest_obj_key = g_variant_get_child_value (val, 0);
+        GVariant *nest_obj_params = g_variant_get_child_value (val, 1);
+        GValue lval = G_VALUE_INIT;
+        GObject *nest_obj =
+          ncm_cfg_create_from_name_params (g_variant_get_string (nest_obj_key, NULL),
+                                           nest_obj_params);
+        g_value_init (&lval, G_TYPE_OBJECT);
+        gprop[i].value = lval;
+        g_value_take_object (&gprop[i].value, nest_obj);
+        g_variant_unref (nest_obj_key);
+        g_variant_unref (nest_obj_params);
+      }
+      else
+        g_dbus_gvariant_to_gvalue (val, &gprop[i].value);
 
-	  i++;
-	  g_variant_unref (var_key);
-	  g_variant_unref (val);
-	  g_variant_unref (var_val);
-	  g_variant_unref (var);
-	}
+      i++;
+      g_variant_unref (var_key);
+      g_variant_unref (val);
+      g_variant_unref (var_val);
+      g_variant_unref (var);
+    }
 
-	obj = g_object_newv (gtype, nprop, gprop);
+    obj = g_object_newv (gtype, nprop, gprop);
 
-	g_free (gprop);
-	g_variant_iter_free (p_iter);
+    g_free (gprop);
+    g_variant_iter_free (p_iter);
   }
   else
-	obj = g_object_new (gtype, NULL);
+    obj = g_object_new (gtype, NULL);
 
   return obj;
 }
@@ -1320,108 +1528,108 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
 {
   switch (t)
   {
-	case G_TYPE_CHAR:
-	case G_TYPE_UCHAR:
-	  return G_VARIANT_TYPE_BYTE;
-	  break;
-	case G_TYPE_BOOLEAN:
-	  return G_VARIANT_TYPE_BOOLEAN;
-	  break;
-	case G_TYPE_INT:
-	{
-	  switch (sizeof (gint))
-	  {
-		case 2:
-		  return G_VARIANT_TYPE_INT16;
-		  break;
-		case 4:
-		  return G_VARIANT_TYPE_INT32;
-		  break;
-		case 8:
-		  return G_VARIANT_TYPE_INT64;
-		  break;
-		default:
-		  g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(gint));
-		  break;
-	  }
-	  break;
-	}
-	case G_TYPE_UINT:
-	{
-	  switch (sizeof (guint))
-	  {
-		case 2:
-		  return G_VARIANT_TYPE_UINT16;
-		  break;
-		case 4:
-		  return G_VARIANT_TYPE_UINT32;
-		  break;
-		case 8:
-		  return G_VARIANT_TYPE_UINT64;
-		  break;
-		default:
-		  g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(guint));
-		  break;
-	  }
-	  break;
-	}
-	case G_TYPE_LONG:
-	{
-	  switch (sizeof (glong))
-	  {
-		case 2:
-		  return G_VARIANT_TYPE_INT16;
-		  break;
-		case 4:
-		  return G_VARIANT_TYPE_INT32;
-		  break;
-		case 8:
-		  return G_VARIANT_TYPE_INT64;
-		  break;
-		default:
-		  g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(glong));
-		  break;
-	  }
-	  break;
-	}
-	case G_TYPE_ULONG:
-	{
-	  switch (sizeof (gulong))
-	  {
-		case 2:
-		  return G_VARIANT_TYPE_UINT16;
-		  break;
-		case 4:
-		  return G_VARIANT_TYPE_UINT32;
-		  break;
-		case 8:
-		  return G_VARIANT_TYPE_UINT64;
-		  break;
-		default:
-		  g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(gulong));
-		  break;
-	  }
-	  break;
-	}
-	case G_TYPE_INT64:
-	  return G_VARIANT_TYPE_INT64;
-	  break;
-	case G_TYPE_UINT64:
-	  return G_VARIANT_TYPE_UINT64;
-	  break;
-	case G_TYPE_FLOAT:
-	case G_TYPE_DOUBLE:
-	  return G_VARIANT_TYPE_DOUBLE;
-	  break;
-	case G_TYPE_STRING:
-	  return G_VARIANT_TYPE_STRING;
-	  break;
-	case G_TYPE_VARIANT:
-	  return G_VARIANT_TYPE_VARIANT;
-	  break;
-	default:
-	  return NULL;
-	  break;
+    case G_TYPE_CHAR:
+    case G_TYPE_UCHAR:
+      return G_VARIANT_TYPE_BYTE;
+      break;
+    case G_TYPE_BOOLEAN:
+      return G_VARIANT_TYPE_BOOLEAN;
+      break;
+    case G_TYPE_INT:
+    {
+      switch (sizeof (gint))
+      {
+        case 2:
+          return G_VARIANT_TYPE_INT16;
+          break;
+        case 4:
+          return G_VARIANT_TYPE_INT32;
+          break;
+        case 8:
+          return G_VARIANT_TYPE_INT64;
+          break;
+        default:
+          g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(gint));
+          break;
+      }
+      break;
+    }
+    case G_TYPE_UINT:
+    {
+      switch (sizeof (guint))
+      {
+        case 2:
+          return G_VARIANT_TYPE_UINT16;
+          break;
+        case 4:
+          return G_VARIANT_TYPE_UINT32;
+          break;
+        case 8:
+          return G_VARIANT_TYPE_UINT64;
+          break;
+        default:
+          g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(guint));
+          break;
+      }
+      break;
+    }
+    case G_TYPE_LONG:
+    {
+      switch (sizeof (glong))
+      {
+        case 2:
+          return G_VARIANT_TYPE_INT16;
+          break;
+        case 4:
+          return G_VARIANT_TYPE_INT32;
+          break;
+        case 8:
+          return G_VARIANT_TYPE_INT64;
+          break;
+        default:
+          g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(glong));
+          break;
+      }
+      break;
+    }
+    case G_TYPE_ULONG:
+    {
+      switch (sizeof (gulong))
+      {
+        case 2:
+          return G_VARIANT_TYPE_UINT16;
+          break;
+        case 4:
+          return G_VARIANT_TYPE_UINT32;
+          break;
+        case 8:
+          return G_VARIANT_TYPE_UINT64;
+          break;
+        default:
+          g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(gulong));
+          break;
+      }
+      break;
+    }
+    case G_TYPE_INT64:
+      return G_VARIANT_TYPE_INT64;
+      break;
+    case G_TYPE_UINT64:
+      return G_VARIANT_TYPE_UINT64;
+      break;
+    case G_TYPE_FLOAT:
+    case G_TYPE_DOUBLE:
+      return G_VARIANT_TYPE_DOUBLE;
+      break;
+    case G_TYPE_STRING:
+      return G_VARIANT_TYPE_STRING;
+      break;
+    case G_TYPE_VARIANT:
+      return G_VARIANT_TYPE_VARIANT;
+      break;
+    default:
+      return NULL;
+      break;
   }
 }
 #endif
@@ -1433,7 +1641,7 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
  * FIXME
  *
  * Returns: (transfer full): A #GVariant convertion of @val.
- */
+   */
 GVariant *
 ncm_cfg_gvalue_to_gvariant (GValue *val)
 #if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
@@ -1445,28 +1653,28 @@ ncm_cfg_gvalue_to_gvariant (GValue *val)
 
   if (var_type == NULL)
   {
-	switch (fund_t)
-	{
-	  case G_TYPE_OBJECT:
-	  {
-		GObject *nest_obj = g_value_get_object (val);
-		if (nest_obj != NULL)
-		  var = ncm_cfg_serialize_to_variant (nest_obj);
-		break;
-	  }
-	  case G_TYPE_ENUM:
-		var = g_variant_ref_sink (g_variant_new_int32 (g_value_get_enum (val)));
-		break;
-	  case G_TYPE_FLAGS:
-		var = g_variant_ref_sink (g_variant_new_uint32 (g_value_get_flags (val)));
-		break;
-	  default:
-		g_error ("Cannot covert GValue '%s' to GVariant.", g_type_name (t));
-		break;
-	}
+    switch (fund_t)
+    {
+      case G_TYPE_OBJECT:
+      {
+        GObject *nest_obj = g_value_get_object (val);
+        if (nest_obj != NULL)
+          var = ncm_cfg_serialize_to_variant (nest_obj);
+        break;
+      }
+      case G_TYPE_ENUM:
+        var = g_variant_ref_sink (g_variant_new_int32 (g_value_get_enum (val)));
+        break;
+      case G_TYPE_FLAGS:
+        var = g_variant_ref_sink (g_variant_new_uint32 (g_value_get_flags (val)));
+        break;
+      default:
+        g_error ("Cannot covert GValue '%s' to GVariant.", g_type_name (t));
+        break;
+    }
   }
   else
-	var = g_dbus_gvalue_to_gvariant (val, var_type);
+    var = g_dbus_gvalue_to_gvariant (val, var_type);
 
   return var;
 }
@@ -1484,7 +1692,7 @@ ncm_cfg_gvalue_to_gvariant (GValue *val)
  * FIXME
  *
  * Returns: (transfer full): A #GVariant dictionary describing the @obj.
- */
+   */
 GVariant *
 ncm_cfg_serialize_to_variant (GObject *obj)
 #if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
@@ -1496,44 +1704,44 @@ ncm_cfg_serialize_to_variant (GObject *obj)
 
   if (n_properties == 0)
   {
-	g_free (prop);
-	return g_variant_ref_sink (g_variant_new ("{sa{sv}}", obj_name, NULL));
+    g_free (prop);
+    return g_variant_ref_sink (g_variant_new ("{sa{sv}}", obj_name, NULL));
   }
   else
   {
-	GVariantBuilder *b = g_variant_builder_new (G_VARIANT_TYPE ("a{sv}"));
-	GVariant *params, *ser_var;
+    GVariantBuilder *b = g_variant_builder_new (G_VARIANT_TYPE ("a{sv}"));
+    GVariant *params, *ser_var;
 
-	for (i = 0; i < n_properties; i++)
-	{
-	  GVariant *var = NULL;
-	  GValue val = G_VALUE_INIT;
+    for (i = 0; i < n_properties; i++)
+    {
+      GVariant *var = NULL;
+      GValue val = G_VALUE_INIT;
 
-	  if (!(prop[i]->flags & G_PARAM_WRITABLE))
-		continue;
+      if (!(prop[i]->flags & G_PARAM_WRITABLE))
+        continue;
 
-	  g_value_init (&val, prop[i]->value_type);
-	  g_object_get_property (obj, prop[i]->name, &val);
+      g_value_init (&val, prop[i]->value_type);
+      g_object_get_property (obj, prop[i]->name, &val);
 
-	  var = ncm_cfg_gvalue_to_gvariant (&val);
-	  if (var == NULL)
-	  {
-		g_value_unset (&val);
-		continue;
-	  }
+      var = ncm_cfg_gvalue_to_gvariant (&val);
+      if (var == NULL)
+      {
+        g_value_unset (&val);
+        continue;
+      }
 
-	  g_variant_builder_add (b, "{sv}", prop[i]->name, var);
+      g_variant_builder_add (b, "{sv}", prop[i]->name, var);
 
-	  g_variant_unref (var);
-	  g_value_unset (&val);
-	}
+      g_variant_unref (var);
+      g_value_unset (&val);
+    }
 
     params = g_variant_builder_end (b);
-	g_variant_builder_unref (b);
-	g_free (prop);
+    g_variant_builder_unref (b);
+    g_free (prop);
 
-	ser_var = g_variant_ref_sink (g_variant_new ("{s@a{sv}}", obj_name, params));
-	return ser_var;
+    ser_var = g_variant_ref_sink (g_variant_new ("{s@a{sv}}", obj_name, params));
+    return ser_var;
   }
 }
 #else
@@ -1552,7 +1760,7 @@ ncm_cfg_serialize_to_variant (GObject *obj)
  *
  *
  * Returns: (transfer full): A string containing the serialized version of @obj.
- */
+   */
 gchar *
 ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant)
 #if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
@@ -1561,25 +1769,25 @@ ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant)
   gchar *ser = NULL;
 
   if (valid_variant)
-	ser = g_variant_print (ser_var, TRUE);
+    ser = g_variant_print (ser_var, TRUE);
   else
   {
-	GVariant *params = NULL;
-	gchar *obj_name = NULL;
-	gchar *params_str;
-	g_variant_get (ser_var, "{s@a{sv}}", &obj_name, &params);
+    GVariant *params = NULL;
+    gchar *obj_name = NULL;
+    gchar *params_str;
+    g_variant_get (ser_var, "{s@a{sv}}", &obj_name, &params);
     if (g_variant_n_children (params) == 0)
-	{
+    {
       ser = obj_name;
-	}
-	else
-	{
-	  params_str = g_variant_print (params, TRUE);
-	  ser = g_strdup_printf ("%s%s", obj_name, params_str);
-	  g_free (params_str);
-	  g_free (obj_name);
-	}
-	g_variant_unref (params);
+    }
+    else
+    {
+      params_str = g_variant_print (params, TRUE);
+      ser = g_strdup_printf ("%s%s", obj_name, params_str);
+      g_free (params_str);
+      g_free (obj_name);
+    }
+    g_variant_unref (params);
   }
   g_variant_unref (ser_var);
   return ser;
@@ -1590,3 +1798,4 @@ ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant)
   return NULL;
 }
 #endif
+ 
\ No newline at end of file
