@@ -24,10 +24,11 @@
 
 /**
  * SECTION:ncm_matrix
- * @title: Matrix
- * @short_description: Allocation and access.
+ * @title: Matrix Object
+ * @short_description: Matrix object representing an array of doubles.
  *
  * This object defines the functions for allocating and accessing matrices.
+ * Also includes serveral matrix operations.
  *
  */
 
@@ -61,6 +62,22 @@ ncm_matrix_new (gsize nrows, gsize ncols)
   return cm;
 }
 
+/**
+ * ncm_matrix_new_sunk:
+ * @nrows: number of rows.
+ * @ncols: number of columns.
+ *
+ * This function allocates memory for a new #NcmMatrix of doubles
+ * with @nrows rows and @ncols columns. Returns a sunk reference.
+ *
+ * Returns: A new #NcmMatrix.
+ */
+NcmMatrix *
+ncm_matrix_new_sunk (gsize nrows, gsize ncols)
+{
+  return ncm_matrix_ref (ncm_matrix_new (nrows, ncols));
+}
+
 /**
  * ncm_matrix_new_gsl: (skip)
  * @gm: matrix from GNU Scientific Library (GSL) to be converted into a #NcmMatrix.
@@ -80,6 +97,23 @@ ncm_matrix_new_gsl (gsl_matrix *gm)
   return cm;
 }
 
+/**
+ * ncm_matrix_new_gsl_static: (skip)
+ * @gm: matrix from GNU Scientific Library (GSL) to be converted into a #NcmMatrix.
+ *
+ * This function saves @gm internally and does not frees it.
+ * The @gm matrix must be valid during the life of the created #NcmMatrix.
+ *
+ * Returns: A new #NcmMatrix.
+ */
+NcmMatrix *
+ncm_matrix_new_gsl_static (gsl_matrix *gm)
+{
+  NcmMatrix *cm = ncm_matrix_new_gsl (gm);
+  cm->type = NCM_MATRIX_DERIVED;
+  return cm;
+}
+
 /**
  * ncm_matrix_new_array:
  * @a: GArray of doubles to be converted into a #NcmMatrix.
@@ -278,26 +312,40 @@ void
 ncm_matrix_free (NcmMatrix *cm)
 {
   if (g_object_is_floating (cm))
-	g_object_ref_sink (cm);
+    g_object_ref_sink (cm);
   g_object_unref (cm);
 }
 
+/**
+ * ncm_matrix_clear:
+ * @cm: a #NcmMatrix.
+ *
+ * Atomically decrements the reference count of @cm by one. If the reference count drops to 0,
+ * all memory allocated by @cm is released. The pointer is set to NULL.
+ *
+ */
+void
+ncm_matrix_clear (NcmMatrix **cm)
+{
+  if (*cm != NULL && g_object_is_floating (*cm))
+    g_object_ref_sink (*cm);
+  g_clear_object (cm);
+}
+
 static void
 _ncm_matrix_dispose (GObject *object)
 {
   NcmMatrix *cm = NCM_MATRIX (object);
-  if (cm->a)
+  
+  if (cm->a != NULL)
   {
-	g_array_unref (cm->a);
-	cm->a = NULL;
+    g_array_unref (cm->a);
+    cm->a = NULL;
   }
 
-  if (cm->pobj)
-  {
-	g_object_unref (cm->pobj);
-	cm->pobj = NULL;
-  }
+  g_clear_object (&cm->pobj);
 
+  /* Chain up : end */
   G_OBJECT_CLASS (ncm_matrix_parent_class)->dispose (object);
 }
 
@@ -325,12 +373,14 @@ _ncm_matrix_finalize (GObject *object)
 	  NCM_MATRIX_DATA (cm) = NULL;
 	  break;
   }
+
+  /* Chain up : end */
   G_OBJECT_CLASS (ncm_matrix_parent_class)->finalize (object);
 }
 
 
 /**
- * ncm_matrix_copy:
+ * ncm_matrix_dup:
  * @cm: a constant #NcmMatrix
  *
  * Duplicates @cm setting the same values of the original propertities.
@@ -338,13 +388,53 @@ _ncm_matrix_finalize (GObject *object)
  * Returns: (transfer full): A #NcmMatrix.
  */
 NcmMatrix *
-ncm_matrix_copy (const NcmMatrix *cm)
+ncm_matrix_dup (const NcmMatrix *cm)
 {
   NcmMatrix *cm_cp = ncm_matrix_new (NCM_MATRIX_COL_LEN (cm), NCM_MATRIX_ROW_LEN (cm));
   ncm_matrix_memcpy (cm_cp, cm);
   return cm_cp;
 }
 
+/**
+ * ncm_matrix_add_mul:
+ * @cm: FIXME
+ * @alpha: FIXME
+ * @b: FIXME
+ *
+ * FIXME
+ *
+ */
+void 
+ncm_matrix_add_mul (NcmMatrix *cm, const gdouble alpha, NcmMatrix *b)
+{
+  const gboolean no_pad_cm = NCM_MATRIX_GSL (cm)->tda == NCM_MATRIX_NCOLS (cm);
+  const gboolean no_pad_b = NCM_MATRIX_GSL (b)->tda == NCM_MATRIX_NCOLS (b);
+
+  g_assert (NCM_MATRIX_NCOLS (cm) == NCM_MATRIX_NCOLS (b));
+  g_assert (NCM_MATRIX_NROWS (cm) == NCM_MATRIX_NROWS (b));
+  
+  if (no_pad_cm && no_pad_b)
+  {
+    const gint N = NCM_MATRIX_NCOLS (b) * NCM_MATRIX_NROWS (b);
+    cblas_daxpy (N, alpha, 
+                 NCM_MATRIX_DATA (b), 1,
+                 NCM_MATRIX_DATA (cm), 1);
+  }
+  else
+  {
+    const gint N = NCM_MATRIX_ROW_LEN (b);
+    const guint b_tda = NCM_MATRIX_GSL (b)->tda;
+    const guint cm_tda = NCM_MATRIX_GSL (cm)->tda;
+    gint i;
+    for (i = 0; i < NCM_MATRIX_NROWS (b); i++)
+    {
+      cblas_daxpy (N, alpha, 
+                   &NCM_MATRIX_DATA (b)[b_tda * i], 1,
+                   &NCM_MATRIX_DATA (cm)[cm_tda * i], 1);
+    }
+  }
+}
+
 /**
  * ncm_matrix_new_gsl_const: (skip)
  * @m: matrix from GNU Scientific Library (GSL).
