@@ -27,9 +27,11 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gsl/gsl_matrix.h>
+
 #include <numcosmo/nc_macros.h>
 #include <numcosmo/math/ncm_vector.h>
+#include <gsl/gsl_matrix.h>
+#include <gsl/gsl_cblas.h>
 
 G_BEGIN_DECLS
 
@@ -96,7 +98,9 @@ GType ncm_matrix_get_type (void) G_GNUC_CONST;
 #define NCM_MATRIX_NCOLS(cm) ((cm)->mv.matrix.size2)
 
 NcmMatrix *ncm_matrix_new (const gsize nrows, const gsize ncols);
+NcmMatrix *ncm_matrix_new_sunk (const gsize nrows, const gsize ncols);
 NcmMatrix *ncm_matrix_new_gsl (gsl_matrix *gm);
+NcmMatrix *ncm_matrix_new_gsl_static (gsl_matrix *gm);
 NcmMatrix *ncm_matrix_new_array (GArray *a, const gsize ncols);
 NcmMatrix *ncm_matrix_new_data_slice (gdouble *d, const gsize nrows, const gsize ncols);
 NcmMatrix *ncm_matrix_new_data_malloc (gdouble *d, const gsize nrows, const gsize ncols);
@@ -120,9 +124,11 @@ G_INLINE_FUNC void ncm_matrix_scale (NcmMatrix *cm, const gdouble val);
 G_INLINE_FUNC void ncm_matrix_memcpy (NcmMatrix *cm1, const NcmMatrix *cm2);
 G_INLINE_FUNC void ncm_matrix_set_col (NcmMatrix *cm, const guint n, const NcmVector *cv);
 
-NcmMatrix *ncm_matrix_copy (const NcmMatrix *cm);
+NcmMatrix *ncm_matrix_dup (const NcmMatrix *cm);
+void ncm_matrix_add_mul (NcmMatrix *cm, const gdouble alpha, NcmMatrix *b);
 
 void ncm_matrix_free (NcmMatrix *cm);
+void ncm_matrix_clear (NcmMatrix **cm);
 
 G_END_DECLS
 
@@ -192,7 +198,7 @@ ncm_matrix_scale (NcmMatrix *cm, gdouble val)
 G_INLINE_FUNC void
 ncm_matrix_memcpy (NcmMatrix *cm1, const NcmMatrix *cm2)
 {
-  gsl_matrix_memcpy (NCM_MATRIX_GSL(cm1), NCM_MATRIX_GSL(cm2));
+  gsl_matrix_memcpy (NCM_MATRIX_GSL (cm1), NCM_MATRIX_GSL (cm2));
 }
 
 G_INLINE_FUNC void
