@@ -24,8 +24,8 @@
 
 /**
  * SECTION:ncm_model_ctrl
- * @title: Model update control object
- * @short_description: FIXME
+ * @title: Model Update Control Object
+ * @short_description: Control object for testing updates on model status
  *
  * FIXME
  */
@@ -56,14 +56,17 @@ static void
 ncm_model_ctrl_dispose (GObject *object)
 {
   NcmModelCtrl *ctrl = NCM_MODEL_CTRL (object);
-  if (ctrl->model)
-	g_object_unref (ctrl->model);
+
+  ncm_model_clear (&ctrl->model);
+
+  /* Chain up : end */
   G_OBJECT_CLASS (ncm_model_ctrl_parent_class)->dispose (object);
 }
 
 static void
 ncm_model_ctrl_finalize (GObject *object)
 {
+  /* Chain up : end */
   G_OBJECT_CLASS (ncm_model_ctrl_parent_class)->finalize (object);
 }
 
@@ -240,3 +243,9 @@ ncm_model_ctrl_free (NcmModelCtrl *ctrl)
 {
   g_object_unref (ctrl);
 }
+
+void
+ncm_model_ctrl_clear (NcmModelCtrl **ctrl)
+{
+  g_clear_object (ctrl);
+}
