@@ -24,11 +24,12 @@
 
 /**
  * SECTION:ncm_spline2d
- * @title: Two Dimensional Spline Abstract Class
- * @short_description: Defines the prototype of the #NcmSpline2d object.
+ * @title: Bidimensional Spline Abstract Class
+ * @short_description: Base class for implementing bidimensional splines
  *
  * This class comprises all functions to provide a #NcmSpline2d, get its properties
  * and evaluate it given an interpolation method.
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -66,20 +67,16 @@ ncm_spline2d_set (NcmSpline2d *s2d, NcmVector *xv, NcmVector *yv, NcmMatrix *zm,
             (ncm_vector_len (xv) >= ncm_spline2d_min_size (s2d)) &&
             (ncm_vector_len (yv) >= ncm_spline2d_min_size (s2d)));
 
-  s2d->xv = xv;
-  ncm_vector_ref (xv);
-  s2d->yv = yv;
-  ncm_vector_ref (yv);
-
-  s2d->zm = zm;
-  ncm_matrix_ref (zm);
+  s2d->xv = ncm_vector_ref (xv);
+  s2d->yv = ncm_vector_ref (yv);
+  s2d->zm = ncm_matrix_ref (zm);
 
   s2d->empty = FALSE;
 
   NCM_SPLINE2D_GET_CLASS (s2d)->reset (s2d);
 
   if (init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
 
   return;
 }
@@ -92,7 +89,7 @@ ncm_spline2d_set (NcmSpline2d *s2d, NcmVector *xv, NcmVector *yv, NcmMatrix *zm,
  * empty #NcmSpline2d of a specific type.
  *
  * Returns: (transfer full): a #NcmSpline2d.
-   */
+ */
 NcmSpline2d *
 ncm_spline2d_copy_empty (const NcmSpline2d *s2d)
 {
@@ -107,19 +104,19 @@ ncm_spline2d_copy_empty (const NcmSpline2d *s2d)
  * spline @s2d into those two #NcmVector and #NcmMatrix of a new #NcmSpline2d.
  *
  * Returns: (transfer full): A #NcmSpline2d.
-   */
+ */
 NcmSpline2d *
 ncm_spline2d_copy (NcmSpline2d *s2d)
 {
   NcmSpline2d *new_s2d = ncm_spline2d_copy_empty (s2d);
   if (!s2d->empty)
   {
-	ncm_spline2d_set (new_s2d,
-	                  ncm_vector_copy (s2d->xv),
-	                  ncm_vector_copy (s2d->yv),
-	                  ncm_matrix_copy (s2d->zm),
-	                  s2d->init
-	                  );
+    ncm_spline2d_set (new_s2d,
+                      ncm_vector_dup (s2d->xv),
+                      ncm_vector_dup (s2d->yv),
+                      ncm_matrix_dup (s2d->zm),
+                      s2d->init
+                      );
   }
 
   return new_s2d;
@@ -139,7 +136,7 @@ ncm_spline2d_copy (NcmSpline2d *s2d)
  * given in the #NcmMatrix @zm.
  *
  * Returns: (transfer full): A new #NcmSpline2d.
-   */
+ */
 NcmSpline2d *
 ncm_spline2d_new (const NcmSpline2d *s2d, NcmVector *xv, NcmVector *yv, NcmMatrix *zm, gboolean init)
 {
@@ -185,6 +182,19 @@ ncm_spline2d_free (NcmSpline2d *s2d)
   g_object_unref (s2d);
 }
 
+/**
+ * ncm_spline2d_clear:
+ * @s2d: a #NcmSpline2d.
+ *
+ * Atomically decrements the reference count of @s2d by one. If the reference count drops to 0,
+ * all memory allocated by @s2d is released. Set pointer to NULL.
+ */
+void
+ncm_spline2d_clear (NcmSpline2d **s2d)
+{
+  g_clear_object (s2d);
+}
+
 /**
  * ncm_spline2d_integ_dx:
  * @s2d: a #NcmSpline2d.
@@ -201,7 +211,7 @@ gdouble
 ncm_spline2d_integ_dx (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble y)
 {
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return NCM_SPLINE2D_GET_CLASS (s2d)->int_dx (s2d, xl, xu, y);
 }
 
@@ -213,15 +223,15 @@ ncm_spline2d_integ_dx (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble y)
  * @yu: upper limit of integration.
  *
  * This function computes the integration in y over the interval [@yl, @yu] and
-   * at @x.
+ * at @x.
  *
  * Returns: The numerical integral in y of an interpolated function over the range [@yl, @yu] and at @x.
-   */
+ */
 gdouble
 ncm_spline2d_integ_dy (NcmSpline2d *s2d, gdouble x, gdouble yl, gdouble yu)
 {
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return NCM_SPLINE2D_GET_CLASS (s2d)->int_dy (s2d, x, yl, yu);
 }
 
@@ -235,14 +245,14 @@ ncm_spline2d_integ_dy (NcmSpline2d *s2d, gdouble x, gdouble yl, gdouble yu)
  *
  * This function computes the integration in both x and y directions over the intervals
  * [@xl, @xu] and [@yl, @yu].
-   *
+ *
  * Returns: The numerical integral in x and y of an interpolated function over the ranges [@xl, @xu] and [@yl, @yu].
-   */
+ */
 gdouble
 ncm_spline2d_integ_dxdy (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble yl, gdouble yu)
 {
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return NCM_SPLINE2D_GET_CLASS (s2d)->int_dxdy (s2d, xl, xu, yl, yu);
 }
 
@@ -254,15 +264,15 @@ ncm_spline2d_integ_dxdy (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble yl, g
  *
  * This function computes the integral in x of the bidimensional interpolated function
  * over the range [@xl, @xu] resulting in a one dimensional function.
-   *
+ *
  * Returns: (transfer full): A #NcmSpline.
-   */
+ */
 NcmSpline *
 ncm_spline2d_integ_dx_spline (NcmSpline2d *s2d, gdouble xl, gdouble xu)
 {
   g_assert (!s2d->empty);
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return ncm_spline_copy (NCM_SPLINE2D_GET_CLASS (s2d)->int_dx_spline (s2d, xl, xu));
 }
 
@@ -281,7 +291,7 @@ NcmSpline *
 ncm_spline2d_integ_dy_spline (NcmSpline2d *s2d, gdouble yl, gdouble yu)
 {
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return ncm_spline_copy (NCM_SPLINE2D_GET_CLASS (s2d)->int_dy_spline (s2d, yl, yu));
 }
 
@@ -301,7 +311,7 @@ gdouble
 ncm_spline2d_integ_dx_spline_val (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble y)
 {
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return ncm_spline_eval (NCM_SPLINE2D_GET_CLASS (s2d)->int_dx_spline (s2d, xl, xu), y);
 }
 
@@ -316,12 +326,12 @@ ncm_spline2d_integ_dx_spline_val (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdou
  * #NcmSpline at @x.
  *
  * Returns: The value of @s2d integrated in y over the range [@yl, @yu] and computed at @x.
-   */
+ */
 gdouble
 ncm_spline2d_integ_dy_spline_val (NcmSpline2d *s2d, gdouble x, gdouble yl, gdouble yu)
 {
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return ncm_spline_eval (NCM_SPLINE2D_GET_CLASS (s2d)->int_dy_spline (s2d, yl, yu), x);
 }
 
@@ -335,14 +345,14 @@ ncm_spline2d_integ_dy_spline_val (NcmSpline2d *s2d, gdouble x, gdouble yl, gdoub
  *
  * This function calls #ncm_spline2d_integ_dx_spline and integrates the resulting
  * #NcmSpline over the interval [@yl, @yu].
-   *
+ *
  * Returns: The value of @s2d integrated in x and y over the ranges [@xl, @xu] and [@yl, @yu], respectively.
-   */
+ */
 gdouble
 ncm_spline2d_integ_dxdy_spline_x (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble yl, gdouble yu)
 {
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return ncm_spline_eval_integ (NCM_SPLINE2D_GET_CLASS (s2d)->int_dx_spline (s2d, xl, xu), yl, yu);
 }
 
@@ -356,14 +366,14 @@ ncm_spline2d_integ_dxdy_spline_x (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdou
  *
  * This function calls #ncm_spline2d_integ_dy_spline and integrates the resulting
  * #NcmSpline over the interval [@xl, @xu].
-   *
+ *
  * Returns: The value of @s2d integrated in x and y over the ranges [@xl, @xu] and [@yl, @yu], respectively.
-   */
+ */
 gdouble
 ncm_spline2d_integ_dxdy_spline_y (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble yl, gdouble yu)
 {
   if (!s2d->init)
-	ncm_spline2d_prepare (s2d);
+    ncm_spline2d_prepare (s2d);
   return ncm_spline_eval_integ (NCM_SPLINE2D_GET_CLASS (s2d)->int_dy_spline (s2d, yl, yu), xl, xu);
 }
 
@@ -409,11 +419,11 @@ typedef struct __NcFunction2D_args
  * @rel_err: relative error between the function to be interpolated and the spline result.
  *
  * This function automatically determines the knots of @s2d in the intervals [@xl, @xu] and
-   * [@yl, @yu] given a @ftype and @rel_error.
-	 *
+ * [@yl, @yu] given a @ftype and @rel_error.
+ *
  * The functions @Fx and @Fy are the bidimensional function given at specific values of y and x, respectively.
  * These x and y values must be in the the intervals [@xl, @xu] and [@yl, @yu].
-   */
+ */
 void
 ncm_spline2d_set_function (NcmSpline2d *s2d, NcmSplineFuncType ftype, gsl_function *Fx, gsl_function *Fy, gdouble xl, gdouble xu, gdouble yl, gdouble yu, gdouble rel_err)
 {
@@ -446,25 +456,15 @@ static void
 ncm_spline2d_dispose (GObject *object)
 {
   NcmSpline2d *s2d = NCM_SPLINE2D (object);
-  if (!s2d->empty)
-  {
-	g_assert (s2d->xv != NULL);
-	g_assert (s2d->yv != NULL);
-	g_assert (s2d->zm != NULL);
 
-	ncm_vector_free (s2d->xv);
-	ncm_vector_free (s2d->yv);
-	ncm_matrix_free (s2d->zm);
+  ncm_vector_clear (&s2d->xv);
+  ncm_vector_clear (&s2d->yv);
+  ncm_matrix_clear (&s2d->zm);
+  ncm_spline_clear (&s2d->s);
 
-	s2d->empty = TRUE;
-
-	s2d->xv = NULL;
-	s2d->yv = NULL;
-	s2d->zm = NULL;
-  }
-
-  ncm_spline_free (s2d->s);
+  s2d->empty = TRUE;
 
+  /* Chain up : end */
   G_OBJECT_CLASS (ncm_spline2d_parent_class)->dispose (object);
 }
 
@@ -484,12 +484,12 @@ _ncm_spline2d_set_property (GObject *object, guint prop_id, const GValue *value,
 
   switch (prop_id)
   {
-	case PROP_SPLINE:
-	  s2d->s = g_value_dup_object (value);
-	  break;
-	default:
-	  G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-	  break;
+    case PROP_SPLINE:
+      s2d->s = g_value_dup_object (value);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
   }
 }
 
@@ -501,12 +501,12 @@ _ncm_spline2d_get_property (GObject *object, guint prop_id, GValue *value, GPara
 
   switch (prop_id)
   {
-	case PROP_SPLINE:
-	  g_value_set_object (value, s2d->s);
-	  break;
-	default:
-	  G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-	  break;
+    case PROP_SPLINE:
+      g_value_set_object (value, s2d->s);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
   }
 }
 
@@ -515,10 +515,10 @@ ncm_spline2d_class_init (NcmSpline2dClass *klass)
 {
   GObjectClass* object_class = G_OBJECT_CLASS (klass);
 
-  object_class->dispose = ncm_spline2d_dispose;
-  object_class->finalize = ncm_spline2d_finalize;
-  object_class->set_property = _ncm_spline2d_set_property;
-  object_class->get_property = _ncm_spline2d_get_property;
+  object_class->set_property = &_ncm_spline2d_set_property;
+  object_class->get_property = &_ncm_spline2d_get_property;
+  object_class->dispose      = &ncm_spline2d_dispose;
+  object_class->finalize     = &ncm_spline2d_finalize;
 
   klass->copy_empty = NULL;
   klass->reset = NULL;
