@@ -24,10 +24,12 @@
 
 /**
  * SECTION:ncm_spline2d_gsl
- * @title: Two Dimensional Spline GSL based
- * @short_description: Abstract class for two dimensional splines.
+ * @title: Bimensional Spline from Spline (GSL)
+ * @short_description: Implements spline from spline method using GSL as base splines
  *
- * This object comprises the proper functions to use the GNU Scientific Library (GSL) spline functions and interpolation methods.
+ * This object implements spline from spline methods using GSL splines as
+ * base objects.
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -90,41 +92,50 @@ _ncm_spline2d_gsl_alloc (NcmSpline2dGsl *s2dgsl)
   NcmSpline2d *s2d = NCM_SPLINE2D (s2dgsl);
   guint i;
 
-  s2dgsl->zdiff = ncm_matrix_new (NCM_MATRIX_COL_LEN (s2d->zm), NCM_MATRIX_ROW_LEN (s2d->zm));
-  s2dgsl->vertv = ncm_vector_new (NCM_MATRIX_COL_LEN (s2d->zm));
-  s2dgsl->vertintv = ncm_vector_new (NCM_MATRIX_COL_LEN (s2d->zm));
+  s2dgsl->s_hor_len = NCM_MATRIX_COL_LEN (s2d->zm);
+  
+  s2dgsl->zdiff = ncm_matrix_new_sunk (s2dgsl->s_hor_len, NCM_MATRIX_ROW_LEN (s2d->zm));
+  s2dgsl->vertv = ncm_vector_new_sunk (s2dgsl->s_hor_len);
+  s2dgsl->vertintv = ncm_vector_new_sunk (s2dgsl->s_hor_len);
 
-  s2dgsl->s_hor = g_slice_alloc (sizeof (NcmSpline *) * NCM_MATRIX_COL_LEN (s2d->zm));
-  for (i = 0; i < NCM_MATRIX_COL_LEN (s2d->zm); i++)
-	s2dgsl->s_hor[i] = ncm_spline_new (s2d->s, s2d->xv, ncm_matrix_get_row (s2d->zm, i), s2d->init);
+  s2dgsl->s_hor = g_new0 (NcmSpline *, s2dgsl->s_hor_len);
+  
+  for (i = 0; i < s2dgsl->s_hor_len; i++)
+    s2dgsl->s_hor[i] = ncm_spline_new (s2d->s, s2d->xv, ncm_matrix_get_row (s2d->zm, i), s2d->init);
 
   s2dgsl->s_ver = ncm_spline_new (s2d->s, s2d->yv, s2dgsl->vertv, FALSE);
   s2dgsl->s_ver_integ = ncm_spline_new (s2d->s, s2d->yv, s2dgsl->vertintv, FALSE);
 
-  s2dgsl->s_dzdy = g_slice_alloc (sizeof (NcmSpline *) * NCM_MATRIX_COL_LEN (s2d->zm));
-  for (i = 0; i < NCM_MATRIX_COL_LEN (s2d->zm); i++)
-	s2dgsl->s_dzdy[i] = ncm_spline_new (s2d->s, s2d->xv, ncm_matrix_get_row (s2dgsl->zdiff, i), s2d->init);
+  s2dgsl->s_dzdy = g_new0 (NcmSpline *, s2dgsl->s_hor_len);
+  for (i = 0; i < s2dgsl->s_hor_len; i++)
+    s2dgsl->s_dzdy[i] = ncm_spline_new (s2d->s, s2d->xv, ncm_matrix_get_row (s2dgsl->zdiff, i), s2d->init);
 
 }
 
+static void
+_ncm_spline2d_gsl_clear (NcmSpline2dGsl *s2dgsl)
+{
+  guint i;
+
+  for (i = 0; i < s2dgsl->s_hor_len; i++)
+    ncm_spline_clear (&s2dgsl->s_hor[i]);
+
+  for (i = 0; i < s2dgsl->s_hor_len; i++)
+    ncm_spline_clear (&s2dgsl->s_dzdy[i]);
+
+  ncm_spline_clear (&s2dgsl->s_ver);
+  ncm_spline_clear (&s2dgsl->s_ver_integ);
+}
+
 static void
 _ncm_spline2d_gsl_free (NcmSpline2dGsl *s2dgsl)
 {
-  NcmSpline2d *s2d = NCM_SPLINE2D (s2dgsl);
-  guint i;
+  _ncm_spline2d_gsl_clear (s2dgsl);
 
-  for (i = 0; i < NCM_MATRIX_COL_LEN (s2d->zm); i++)
-	ncm_spline_free (s2dgsl->s_hor[i]);
-
-  g_slice_free1 (sizeof (NcmSpline *) * NCM_MATRIX_COL_LEN (s2d->zm), s2dgsl->s_hor);
-
-  for (i = 0; i < NCM_MATRIX_COL_LEN (s2dgsl->zdiff); i++)
-	ncm_spline_free (s2dgsl->s_dzdy[i]);
-
-  g_slice_free1 (sizeof (NcmSpline *) * NCM_MATRIX_COL_LEN (s2dgsl->zdiff), s2dgsl->s_dzdy);
-
-  ncm_spline_free (s2dgsl->s_ver);
-  ncm_spline_free (s2dgsl->s_ver_integ);
+  g_free (s2dgsl->s_hor);
+  s2dgsl->s_hor = NULL;
+  g_free (s2dgsl->s_dzdy);
+  s2dgsl->s_dzdy = NULL;
 }
 
 static void
@@ -133,15 +144,15 @@ _ncm_spline2d_gsl_reset (NcmSpline2d *s2d)
   NcmSpline2dGsl *s2dgsl = NCM_SPLINE2D_GSL (s2d);
   if (s2d->init)
   {
-	if ((NCM_MATRIX_NROWS (s2d->zm) != ncm_vector_len (s2dgsl->vertv)) ||
-	    (NCM_MATRIX_NCOLS (s2d->zm) != ncm_vector_len (s2dgsl->s_hor[0]->xv)))
-	{
-	  _ncm_spline2d_gsl_free (s2dgsl);
-	  _ncm_spline2d_gsl_alloc (s2dgsl);
-	}
+    if ((NCM_MATRIX_NROWS (s2d->zm) != ncm_vector_len (s2dgsl->vertv)) ||
+        (NCM_MATRIX_NCOLS (s2d->zm) != ncm_vector_len (s2dgsl->s_hor[0]->xv)))
+    {
+      _ncm_spline2d_gsl_free (s2dgsl);
+      _ncm_spline2d_gsl_alloc (s2dgsl);
+    }
   }
   else
-	_ncm_spline2d_gsl_alloc (s2dgsl);
+    _ncm_spline2d_gsl_alloc (s2dgsl);
 }
 
 
@@ -151,25 +162,25 @@ _ncm_spline2d_gsl_prepare (NcmSpline2d *s2d)
   NcmSpline2dGsl *s2dgsl = NCM_SPLINE2D_GSL (s2d);
 
   guint i, j;
-  for (i = 0; i < NCM_MATRIX_COL_LEN (s2d->zm); i++)
-	ncm_spline_prepare (s2dgsl->s_hor[i]);
+  for (i = 0; i < s2dgsl->s_hor_len; i++)
+    ncm_spline_prepare (s2dgsl->s_hor[i]);
 
   for (j = 0; j < NCM_MATRIX_ROW_LEN (s2d->zm); j++)
   {
-	for (i = 0; i < NCM_MATRIX_COL_LEN (s2d->zm); i++)
-	  ncm_vector_set (s2dgsl->vertv, i, ncm_matrix_get (s2d->zm, i, j));
-	ncm_spline_prepare (s2dgsl->s_ver);
+    for (i = 0; i < s2dgsl->s_hor_len; i++)
+      ncm_vector_set (s2dgsl->vertv, i, ncm_matrix_get (s2d->zm, i, j));
+    ncm_spline_prepare (s2dgsl->s_ver);
 
-	for (i = 0; i < NCM_MATRIX_COL_LEN (s2d->zm); i++)
-	{
-	  const gdouble yi = ncm_vector_get (s2d->yv, i);
-	  const gdouble diff_val = ncm_spline_eval_deriv (s2dgsl->s_ver, yi);
-	  ncm_matrix_set (s2dgsl->zdiff, i, j, diff_val);
-	}
+    for (i = 0; i < s2dgsl->s_hor_len; i++)
+    {
+      const gdouble yi = ncm_vector_get (s2d->yv, i);
+      const gdouble diff_val = ncm_spline_eval_deriv (s2dgsl->s_ver, yi);
+      ncm_matrix_set (s2dgsl->zdiff, i, j, diff_val);
+    }
   }
 
-  for (i = 0; i < NCM_MATRIX_COL_LEN (s2d->zm); i++)
-	ncm_spline_prepare (s2dgsl->s_dzdy[i]);
+  for (i = 0; i < s2dgsl->s_hor_len; i++)
+    ncm_spline_prepare (s2dgsl->s_dzdy[i]);
 
   s2d->init = TRUE;
 }
@@ -246,8 +257,8 @@ static gdouble _ncm_spline2d_gsl_dzdx (NcmSpline2d *s2d, gdouble x, gdouble y)
   _ncm_bicubic_calc_aij (s2dgsl, i, j, x0, x1, y0, y1, &a);
 
   result = a.ij[1][0] + a.ij[1][1] * dy + a.ij[1][2] * dy2 + a.ij[1][3] * dy3
-	+ 2.0 * (a.ij[2][0] + a.ij[2][1] * dy + a.ij[2][2] * dy2 + a.ij[2][3] * dy3) * dx
-	+ 3.0 * (a.ij[3][0] + a.ij[3][1] * dy + a.ij[3][2] * dy2 + a.ij[3][3] * dy3) * dx2;
+    + 2.0 * (a.ij[2][0] + a.ij[2][1] * dy + a.ij[2][2] * dy2 + a.ij[2][3] * dy3) * dx
+    + 3.0 * (a.ij[3][0] + a.ij[3][1] * dy + a.ij[3][2] * dy2 + a.ij[3][3] * dy3) * dx2;
 
   return result;
 }
@@ -275,8 +286,8 @@ static gdouble _ncm_spline2d_gsl_dzdy (NcmSpline2d *s2d, gdouble x, gdouble y)
   _ncm_bicubic_calc_aij (s2dgsl, i, j, x0, x1, y0, y1, &a);
 
   result = a.ij[0][1] + a.ij[1][1] * dx + a.ij[2][1] * dx2 + a.ij[3][1] * dx3
-	+ 2.0 * (a.ij[0][2] + a.ij[1][2] * dx + a.ij[2][2] * dx2 + a.ij[3][2] * dx3) * dy
-	+ 3.0 * (a.ij[0][3] + a.ij[1][3] * dx + a.ij[2][3] * dx2 + a.ij[3][3] * dx3) * dy2;
+    + 2.0 * (a.ij[0][2] + a.ij[1][2] * dx + a.ij[2][2] * dx2 + a.ij[3][2] * dx3) * dy
+    + 3.0 * (a.ij[0][3] + a.ij[1][3] * dx + a.ij[2][3] * dx2 + a.ij[3][3] * dx3) * dy2;
 
   return result;
 }
@@ -303,7 +314,7 @@ static gdouble _ncm_spline2d_gsl_d2zdx2 (NcmSpline2d *s2d, gdouble x, gdouble y)
   _ncm_bicubic_calc_aij (s2dgsl, i, j, x0, x1, y0, y1, &a);
 
   result = 2.0 * (a.ij[2][0] + a.ij[2][1] * dy + a.ij[2][2] * dy2 + a.ij[2][3] * dy3)
-	+ 6.0 * (a.ij[3][0] + a.ij[3][1] * dy + a.ij[3][2] * dy2 + a.ij[3][3] * dy3) * dx;
+    + 6.0 * (a.ij[3][0] + a.ij[3][1] * dy + a.ij[3][2] * dy2 + a.ij[3][3] * dy3) * dx;
 
   return result;
 }
@@ -330,7 +341,7 @@ static gdouble _ncm_spline2d_gsl_d2zdy2 (NcmSpline2d *s2d, gdouble x, gdouble y)
   _ncm_bicubic_calc_aij (s2dgsl, i, j, x0, x1, y0, y1, &a);
 
   result = 2.0 * (a.ij[0][2] + a.ij[1][2] * dx + a.ij[2][2] * dx2 + a.ij[3][2] * dx3)
-	+ 6.0 * (a.ij[0][3] + a.ij[1][3] * dx + a.ij[2][3] * dx2 + a.ij[3][3] * dx3) * dy;
+    + 6.0 * (a.ij[0][3] + a.ij[1][3] * dx + a.ij[2][3] * dx2 + a.ij[3][3] * dx3) * dy;
 
   return result;
 }
@@ -357,8 +368,8 @@ static gdouble _ncm_spline2d_gsl_d2zdxy (NcmSpline2d *s2d, gdouble x, gdouble y)
   _ncm_bicubic_calc_aij (s2dgsl, i, j, x0, x1, y0, y1, &a);
 
   result = a.ij[1][1] + 2.0 * (a.ij[2][1] * dx + a.ij[1][2] * dy) + 4.0 * a.ij[2][2] * dx * dy
-	+ 3.0 * (a.ij[3][1] * dx2 + a.ij[1][3] * dy2) + 9.0 * a.ij[3][3] * dx2 * dy2
-	+ 6.0 * (a.ij[3][2] * dx2 * dy + a.ij[2][3] * dx * dy2);
+    + 3.0 * (a.ij[3][1] * dx2 + a.ij[1][3] * dy2) + 9.0 * a.ij[3][3] * dx2 * dy2
+    + 6.0 * (a.ij[3][2] * dx2 * dy + a.ij[2][3] * dx * dy2);
 
   return result;
 }
@@ -382,40 +393,40 @@ _ncm_spline2d_gsl_int_dx (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble y)
 
   if (jl == ju)
   {
-	x0 = ncm_vector_get (s2d->xv, jl);
-	x1 = ncm_vector_get (s2d->xv, jl + 1);
-	_ncm_bicubic_calc_aij (s2dgsl, i, jl, x0, x1, y0, y1, &aij);
-	ncm_spline2d_bicubic_integ_dx_coeffs (&aij, y - y0, coeffs);
-	result = _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], x0, xl, xu);
+    x0 = ncm_vector_get (s2d->xv, jl);
+    x1 = ncm_vector_get (s2d->xv, jl + 1);
+    _ncm_bicubic_calc_aij (s2dgsl, i, jl, x0, x1, y0, y1, &aij);
+    ncm_spline2d_bicubic_integ_dx_coeffs (&aij, y - y0, coeffs);
+    result = _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], x0, xl, xu);
   }
   else
   {
-	x0 = ncm_vector_get (s2d->xv, jl);
-	x1 = ncm_vector_get (s2d->xv, jl + 1);
-	_ncm_bicubic_calc_aij (s2dgsl, i, jl, x0, x1, y0, y1, &aij);
-	ncm_spline2d_bicubic_integ_dx_coeffs (&aij, y - y0, coeffs);
-	result = _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], x0, xl, x1);
+    x0 = ncm_vector_get (s2d->xv, jl);
+    x1 = ncm_vector_get (s2d->xv, jl + 1);
+    _ncm_bicubic_calc_aij (s2dgsl, i, jl, x0, x1, y0, y1, &aij);
+    ncm_spline2d_bicubic_integ_dx_coeffs (&aij, y - y0, coeffs);
+    result = _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], x0, xl, x1);
 
-	for (k = jl + 1; k < ju; k++)
-	{
-	  x0 = ncm_vector_get (s2d->xv, k);
-	  x1 = ncm_vector_get (s2d->xv, k + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, i, k, x0, x1, y0, y1, &aij);
-	  ncm_spline2d_bicubic_integ_dx_coeffs (&aij, y - y0, coeffs);
+    for (k = jl + 1; k < ju; k++)
+    {
+      x0 = ncm_vector_get (s2d->xv, k);
+      x1 = ncm_vector_get (s2d->xv, k + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, i, k, x0, x1, y0, y1, &aij);
+      ncm_spline2d_bicubic_integ_dx_coeffs (&aij, y - y0, coeffs);
 
-	  {
-		const gdouble dx = x1 - x0;
-		result += dx * (coeffs[0] + dx * (0.5 * coeffs[1] + dx * (coeffs[2] / 3.0 + 0.25 * coeffs[3] * dx)));
-	  }
-	}
-	k = ju;
-	{
-	  x0 = ncm_vector_get (s2d->xv, ju);
-	  x1 = ncm_vector_get (s2d->xv, ju + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, i, ju, x0, x1, y0, y1, &aij);
-	  ncm_spline2d_bicubic_integ_dx_coeffs (&aij, y - y0, coeffs);
-	  result += _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], x0, x0, xu);
-	}
+      {
+        const gdouble dx = x1 - x0;
+        result += dx * (coeffs[0] + dx * (0.5 * coeffs[1] + dx * (coeffs[2] / 3.0 + 0.25 * coeffs[3] * dx)));
+      }
+    }
+    k = ju;
+    {
+      x0 = ncm_vector_get (s2d->xv, ju);
+      x1 = ncm_vector_get (s2d->xv, ju + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, i, ju, x0, x1, y0, y1, &aij);
+      ncm_spline2d_bicubic_integ_dx_coeffs (&aij, y - y0, coeffs);
+      result += _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], x0, x0, xu);
+    }
   }
 
   return result;
@@ -440,40 +451,40 @@ _ncm_spline2d_gsl_int_dy (NcmSpline2d *s2d, gdouble x, gdouble yl, gdouble yu)
 
   if (il == iu)
   {
-	y0 = ncm_vector_get (s2d->yv, il);
-	y1 = ncm_vector_get (s2d->yv, il + 1);
-	_ncm_bicubic_calc_aij (s2dgsl, il, j, x0, x1, y0, y1, &aij);
-	ncm_spline2d_bicubic_integ_dy_coeffs (&aij, x - x0, coeffs);
-	result = _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], y0, yl, yu);
+    y0 = ncm_vector_get (s2d->yv, il);
+    y1 = ncm_vector_get (s2d->yv, il + 1);
+    _ncm_bicubic_calc_aij (s2dgsl, il, j, x0, x1, y0, y1, &aij);
+    ncm_spline2d_bicubic_integ_dy_coeffs (&aij, x - x0, coeffs);
+    result = _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], y0, yl, yu);
   }
   else
   {
-	y0 = ncm_vector_get (s2d->yv, il);
-	y1 = ncm_vector_get (s2d->yv, il + 1);
-	_ncm_bicubic_calc_aij (s2dgsl, il, j, x0, x1, y0, y1, &aij);
-	ncm_spline2d_bicubic_integ_dy_coeffs (&aij, x - x0, coeffs);
-	result = _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], y0, yl, y1);
+    y0 = ncm_vector_get (s2d->yv, il);
+    y1 = ncm_vector_get (s2d->yv, il + 1);
+    _ncm_bicubic_calc_aij (s2dgsl, il, j, x0, x1, y0, y1, &aij);
+    ncm_spline2d_bicubic_integ_dy_coeffs (&aij, x - x0, coeffs);
+    result = _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], y0, yl, y1);
 
-	for (k = il + 1; k < iu; k++)
-	{
-	  y0 = ncm_vector_get (s2d->yv, k);
-	  y1 = ncm_vector_get (s2d->yv, k + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, k, j, x0, x1, y0, y1, &aij);
-	  ncm_spline2d_bicubic_integ_dy_coeffs (&aij, x - x0, coeffs);
+    for (k = il + 1; k < iu; k++)
+    {
+      y0 = ncm_vector_get (s2d->yv, k);
+      y1 = ncm_vector_get (s2d->yv, k + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, k, j, x0, x1, y0, y1, &aij);
+      ncm_spline2d_bicubic_integ_dy_coeffs (&aij, x - x0, coeffs);
 
-	  {
-		const gdouble dy = y1 - y0;
-		result += dy * (coeffs[0] + dy * (0.5 * coeffs[1] + dy * (coeffs[2] / 3.0 + 0.25 * coeffs[3] * dy)));
-	  }
-	}
-	k = iu;
-	{
-	  y0 = ncm_vector_get (s2d->yv, k);
-	  y1 = ncm_vector_get (s2d->yv, k + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, k, j, x0, x1, y0, y1, &aij);
-	  ncm_spline2d_bicubic_integ_dy_coeffs (&aij, x - x0, coeffs);
-	  result += _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], y0, y0, yu);
-	}
+      {
+        const gdouble dy = y1 - y0;
+        result += dy * (coeffs[0] + dy * (0.5 * coeffs[1] + dy * (coeffs[2] / 3.0 + 0.25 * coeffs[3] * dy)));
+      }
+    }
+    k = iu;
+    {
+      y0 = ncm_vector_get (s2d->yv, k);
+      y1 = ncm_vector_get (s2d->yv, k + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, k, j, x0, x1, y0, y1, &aij);
+      ncm_spline2d_bicubic_integ_dy_coeffs (&aij, x - x0, coeffs);
+      result += _ncm_spline_util_integ_eval (coeffs[0], coeffs[1], coeffs[2], coeffs[3], y0, y0, yu);
+    }
   }
 
   return result;
@@ -496,130 +507,130 @@ _ncm_spline2d_gsl_int_dxdy (NcmSpline2d *s2d, gdouble xl, gdouble xu, gdouble yl
 
   if (jl == ju && il == iu)
   {
-	x0 = ncm_vector_get (s2d->xv, jl);
-	x1 = ncm_vector_get (s2d->xv, jl + 1);
-	y0 = ncm_vector_get (s2d->yv, il);
-	y1 = ncm_vector_get (s2d->yv, il + 1);
-	_ncm_bicubic_calc_aij (s2dgsl, il, jl, x0, x1, y0, y1, &aij);
-	result = ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, xu, y0, yl, yu);
+    x0 = ncm_vector_get (s2d->xv, jl);
+    x1 = ncm_vector_get (s2d->xv, jl + 1);
+    y0 = ncm_vector_get (s2d->yv, il);
+    y1 = ncm_vector_get (s2d->yv, il + 1);
+    _ncm_bicubic_calc_aij (s2dgsl, il, jl, x0, x1, y0, y1, &aij);
+    result = ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, xu, y0, yl, yu);
   }
   else if (jl == ju)
   {
-	x0 = ncm_vector_get (s2d->xv, jl);
-	x1 = ncm_vector_get (s2d->xv, jl + 1);
-	y0 = ncm_vector_get (s2d->yv, il);
-	y1 = ncm_vector_get (s2d->yv, il + 1);
-	_ncm_bicubic_calc_aij (s2dgsl, il, jl, x0, x1, y0, y1, &aij);
-	result = ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, xu, y0, yl, y1);
-	for (k = il + 1; k < iu; k++)
-	{
-	  y0 = ncm_vector_get (s2d->yv, k);
-	  y1 = ncm_vector_get (s2d->yv, k + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, k, jl, x0, x1, y0, y1, &aij);
-	  result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, xu, y0, y0, y1);
-	}
-	k = iu;
-	{
-	  y0 = ncm_vector_get (s2d->yv, k);
-	  y1 = ncm_vector_get (s2d->yv, k + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, k, jl, x0, x1, y0, y1, &aij);
-	  result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, xu, y0, y0, yu);
-	}
+    x0 = ncm_vector_get (s2d->xv, jl);
+    x1 = ncm_vector_get (s2d->xv, jl + 1);
+    y0 = ncm_vector_get (s2d->yv, il);
+    y1 = ncm_vector_get (s2d->yv, il + 1);
+    _ncm_bicubic_calc_aij (s2dgsl, il, jl, x0, x1, y0, y1, &aij);
+    result = ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, xu, y0, yl, y1);
+    for (k = il + 1; k < iu; k++)
+    {
+      y0 = ncm_vector_get (s2d->yv, k);
+      y1 = ncm_vector_get (s2d->yv, k + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, k, jl, x0, x1, y0, y1, &aij);
+      result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, xu, y0, y0, y1);
+    }
+    k = iu;
+    {
+      y0 = ncm_vector_get (s2d->yv, k);
+      y1 = ncm_vector_get (s2d->yv, k + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, k, jl, x0, x1, y0, y1, &aij);
+      result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, xu, y0, y0, yu);
+    }
   }
   else if (il == iu)
   {
-	x0 = ncm_vector_get (s2d->xv, jl);
-	x1 = ncm_vector_get (s2d->xv, jl + 1);
-	y0 = ncm_vector_get (s2d->yv, il);
-	y1 = ncm_vector_get (s2d->yv, il + 1);
-	_ncm_bicubic_calc_aij (s2dgsl, il, jl, x0, x1, y0, y1, &aij);
-	result = ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, x1, y0, yl, yu);
-	for (k = jl + 1; k < ju; k++)
-	{
-	  x0 = ncm_vector_get (s2d->xv, k);
-	  x1 = ncm_vector_get (s2d->xv, k + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, il, k, x0, x1, y0, y1, &aij);
-	  result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, x1, y0, yl, yu);
-	}
-	k = ju;
-	{
-	  x0 = ncm_vector_get (s2d->xv, k);
-	  x1 = ncm_vector_get (s2d->xv, k + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, il, k, x0, x1, y0, y1, &aij);
-	  result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, xu, y0, yl, yu);
-	}
+    x0 = ncm_vector_get (s2d->xv, jl);
+    x1 = ncm_vector_get (s2d->xv, jl + 1);
+    y0 = ncm_vector_get (s2d->yv, il);
+    y1 = ncm_vector_get (s2d->yv, il + 1);
+    _ncm_bicubic_calc_aij (s2dgsl, il, jl, x0, x1, y0, y1, &aij);
+    result = ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, x1, y0, yl, yu);
+    for (k = jl + 1; k < ju; k++)
+    {
+      x0 = ncm_vector_get (s2d->xv, k);
+      x1 = ncm_vector_get (s2d->xv, k + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, il, k, x0, x1, y0, y1, &aij);
+      result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, x1, y0, yl, yu);
+    }
+    k = ju;
+    {
+      x0 = ncm_vector_get (s2d->xv, k);
+      x1 = ncm_vector_get (s2d->xv, k + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, il, k, x0, x1, y0, y1, &aij);
+      result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, xu, y0, yl, yu);
+    }
   }
   else
   {
-	m = jl;
-	{
-	  x0 = ncm_vector_get (s2d->xv, jl);
-	  x1 = ncm_vector_get (s2d->xv, jl + 1);
-	  y0 = ncm_vector_get (s2d->yv, il);
-	  y1 = ncm_vector_get (s2d->yv, il + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, il, m, x0, x1, y0, y1, &aij);
-	  result = ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, x1, y0, yl, y1);
-	  for (k = il + 1; k < iu; k++)
-	  {
-		y0 = ncm_vector_get (s2d->yv, k);
-		y1 = ncm_vector_get (s2d->yv, k + 1);
-		_ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
-		result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, x1, y0, y0, y1);
-	  }
-	  k = iu;
-	  {
-		y0 = ncm_vector_get (s2d->yv, k);
-		y1 = ncm_vector_get (s2d->yv, k + 1);
-		_ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
-		result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, x1, y0, y0, yu);
-	  }
-	}
-	for (m = jl + 1; m < ju; m++)
-	{
-	  x0 = ncm_vector_get (s2d->xv, m);
-	  x1 = ncm_vector_get (s2d->xv, m + 1);
-	  y0 = ncm_vector_get (s2d->yv, il);
-	  y1 = ncm_vector_get (s2d->yv, il + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, il, m, x0, x1, y0, y1, &aij);
-	  result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, x1, y0, yl, y1);
-	  for (k = il + 1; k < iu; k++)
-	  {
-		y0 = ncm_vector_get (s2d->yv, k);
-		y1 = ncm_vector_get (s2d->yv, k + 1);
-		_ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
-		result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, x1, y0, y0, y1);
-	  }
-	  k = iu;
-	  {
-		y0 = ncm_vector_get (s2d->yv, k);
-		y1 = ncm_vector_get (s2d->yv, k + 1);
-		_ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
-		result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, x1, y0, y0, yu);
-	  }
-	}
-	m = ju;
-	{
-	  x0 = ncm_vector_get (s2d->xv, m);
-	  x1 = ncm_vector_get (s2d->xv, m + 1);
-	  y0 = ncm_vector_get (s2d->yv, il);
-	  y1 = ncm_vector_get (s2d->yv, il + 1);
-	  _ncm_bicubic_calc_aij (s2dgsl, il, m, x0, x1, y0, y1, &aij);
-	  result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, xu, y0, yl, y1);
-	  for (k = il + 1; k < iu; k++)
-	  {
-		y0 = ncm_vector_get (s2d->yv, k);
-		y1 = ncm_vector_get (s2d->yv, k + 1);
-		_ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
-		result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, xu, y0, y0, y1);
-	  }
-	  k = iu;
-	  {
-		y0 = ncm_vector_get (s2d->yv, k);
-		y1 = ncm_vector_get (s2d->yv, k + 1);
-		_ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
-		result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, xu, y0, y0, yu);
-	  }
-	}
+    m = jl;
+    {
+      x0 = ncm_vector_get (s2d->xv, jl);
+      x1 = ncm_vector_get (s2d->xv, jl + 1);
+      y0 = ncm_vector_get (s2d->yv, il);
+      y1 = ncm_vector_get (s2d->yv, il + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, il, m, x0, x1, y0, y1, &aij);
+      result = ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, x1, y0, yl, y1);
+      for (k = il + 1; k < iu; k++)
+      {
+        y0 = ncm_vector_get (s2d->yv, k);
+        y1 = ncm_vector_get (s2d->yv, k + 1);
+        _ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
+        result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, x1, y0, y0, y1);
+      }
+      k = iu;
+      {
+        y0 = ncm_vector_get (s2d->yv, k);
+        y1 = ncm_vector_get (s2d->yv, k + 1);
+        _ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
+        result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, xl, x1, y0, y0, yu);
+      }
+    }
+    for (m = jl + 1; m < ju; m++)
+    {
+      x0 = ncm_vector_get (s2d->xv, m);
+      x1 = ncm_vector_get (s2d->xv, m + 1);
+      y0 = ncm_vector_get (s2d->yv, il);
+      y1 = ncm_vector_get (s2d->yv, il + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, il, m, x0, x1, y0, y1, &aij);
+      result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, x1, y0, yl, y1);
+      for (k = il + 1; k < iu; k++)
+      {
+        y0 = ncm_vector_get (s2d->yv, k);
+        y1 = ncm_vector_get (s2d->yv, k + 1);
+        _ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
+        result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, x1, y0, y0, y1);
+      }
+      k = iu;
+      {
+        y0 = ncm_vector_get (s2d->yv, k);
+        y1 = ncm_vector_get (s2d->yv, k + 1);
+        _ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
+        result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, x1, y0, y0, yu);
+      }
+    }
+    m = ju;
+    {
+      x0 = ncm_vector_get (s2d->xv, m);
+      x1 = ncm_vector_get (s2d->xv, m + 1);
+      y0 = ncm_vector_get (s2d->yv, il);
+      y1 = ncm_vector_get (s2d->yv, il + 1);
+      _ncm_bicubic_calc_aij (s2dgsl, il, m, x0, x1, y0, y1, &aij);
+      result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, xu, y0, yl, y1);
+      for (k = il + 1; k < iu; k++)
+      {
+        y0 = ncm_vector_get (s2d->yv, k);
+        y1 = ncm_vector_get (s2d->yv, k + 1);
+        _ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
+        result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, xu, y0, y0, y1);
+      }
+      k = iu;
+      {
+        y0 = ncm_vector_get (s2d->yv, k);
+        y1 = ncm_vector_get (s2d->yv, k + 1);
+        _ncm_bicubic_calc_aij (s2dgsl, k, m, x0, x1, y0, y1, &aij);
+        result += ncm_spline2d_bicubic_integ_eval2d (&aij, x0, x0, xu, y0, y0, yu);
+      }
+    }
   }
 
   return result;
@@ -640,13 +651,14 @@ _ncm_spline2d_gsl_int_dy_spline (NcmSpline2d *s2d, gdouble yl, gdouble yu)
 static void
 ncm_spline2d_gsl_init (NcmSpline2dGsl *s2dgsl)
 {
-  s2dgsl->zdiff = NULL;
-  s2dgsl->vertv = NULL;
-  s2dgsl->vertintv = NULL;
-  s2dgsl->s_hor = NULL;
-  s2dgsl->s_dzdy = NULL;
-  s2dgsl->s_ver = NULL;
+  s2dgsl->zdiff       = NULL;
+  s2dgsl->vertv       = NULL;
+  s2dgsl->vertintv    = NULL;
+  s2dgsl->s_hor       = NULL;
+  s2dgsl->s_dzdy      = NULL;
+  s2dgsl->s_ver       = NULL;
   s2dgsl->s_ver_integ = NULL;
+  s2dgsl->s_hor_len   = 0;
 }
 
 static void
@@ -654,18 +666,32 @@ ncm_spline2d_gsl_dispose (GObject *object)
 {
   NcmSpline2d *s2d = NCM_SPLINE2D (object);
   NcmSpline2dGsl *s2dgsl = NCM_SPLINE2D_GSL (object);
-  if (s2d->init)
-  {
-	_ncm_spline2d_gsl_free (s2dgsl);
-	s2d->init = FALSE;
-  }
 
+  _ncm_spline2d_gsl_clear (s2dgsl);
+  s2d->init = FALSE;
+
+  /* Chain up : end */
   G_OBJECT_CLASS (ncm_spline2d_gsl_parent_class)->dispose (object);
 }
 
 static void
 ncm_spline2d_gsl_finalize (GObject *object)
 {
+  NcmSpline2dGsl *s2dgsl = NCM_SPLINE2D_GSL (object);
+
+  if (s2dgsl->s_hor != NULL)
+  {
+    g_free (s2dgsl->s_hor);
+    s2dgsl->s_hor = NULL;
+  }
+
+  if (s2dgsl->s_dzdy != NULL)
+  {
+    g_free (s2dgsl->s_dzdy);
+    s2dgsl->s_dzdy = NULL;
+  }
+
+  /* Chain up : end */
   G_OBJECT_CLASS (ncm_spline2d_gsl_parent_class)->finalize (object);
 }
 
