@@ -24,11 +24,12 @@
 
 /**
  * SECTION:ncm_spline_cubic
- * @title: Cubic Spline
- * @short_description: Abstract class for cubic splines.
+ * @title: Cubic Spline Abstract Class
+ * @short_description: Base class for implementing cubic splines
  *
  * This class implements the functions which use a polynomial interpolation
- * method of third degree, except that one which prepares the spline.
+ * method of third degree.
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,13 +46,13 @@ _ncm_spline_cubic_alloc (NcmSplineCubic *sc, gsize n)
 {
 	g_assert (!sc->init);
 
-	sc->b = ncm_vector_new (n);
-	sc->c = ncm_vector_new (n);
-	sc->d = ncm_vector_new (n);
+	sc->b = ncm_vector_new_sunk (n);
+	sc->c = ncm_vector_new_sunk (n);
+	sc->d = ncm_vector_new_sunk (n);
 
-	sc->g = ncm_vector_new (n);
-	sc->diag = ncm_vector_new (n);
-	sc->offdiag = ncm_vector_new (n);
+	sc->g = ncm_vector_new_sunk (n);
+	sc->diag = ncm_vector_new_sunk (n);
+	sc->offdiag = ncm_vector_new_sunk (n);
 
 	sc->init = TRUE;
 	sc->len = n;
@@ -204,6 +205,7 @@ ncm_spline_cubic_finalize (GObject *object)
 	NcmSplineCubic *sc = NCM_SPLINE_CUBIC (object);
 	_ncm_spline_cubic_free (sc);
 
+  /* Chain up : end */
 	G_OBJECT_CLASS (ncm_spline_cubic_parent_class)->finalize (object);
 }
 
