@@ -24,10 +24,12 @@
 
 /**
  * SECTION:ncm_vector
- * @title: Vector
- * @short_description: Allocation, access and operations.
+ * @title: Vector Object
+ * @short_description: Vector object representing arrays of doubles
  *
  * This object defines the functions for allocating and accessing vectors.
+ * Also includes several vector operations.
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,6 +57,21 @@ ncm_vector_new (gsize n)
   return ncm_vector_new_data_slice (d, n, 1);
 }
 
+/**
+ * ncm_vector_new_sunk:
+ * @n: defines the size of the vector.
+ *
+ * This function allocates memory for a new #NcmVector of double
+ * with @n components. Returns a sunk reference.
+ *
+ * Returns: A new #NcmVector.
+ */
+NcmVector *
+ncm_vector_new_sunk (gsize n)
+{
+  return ncm_vector_ref (ncm_vector_new (n));
+}
+
 /**
  * ncm_vector_new_gsl: (skip)
  * @gv: vector from GNU Scientific Library (GSL) to be converted into a #NcmVector.
@@ -77,6 +94,23 @@ ncm_vector_new_gsl (gsl_vector *gv)
   return cv;
 }
 
+/**
+ * ncm_vector_new_gsl_static: (skip)
+ * @gv: vector from GNU Scientific Library (GSL) to be converted into a #NcmVector.
+ * 
+ * This function saves @gv internally and does not frees.
+ * The @gv vector must be valid during the life of the created #NcmVector.
+ * 
+ * Returns: A new #NcmVector.
+ */
+NcmVector *
+ncm_vector_new_gsl_static (gsl_vector *gv)
+{
+  NcmVector *cv = ncm_vector_new_gsl (gv);
+  cv->type = NCM_VECTOR_DERIVED;
+  return cv;
+}
+
 /**
  * ncm_vector_new_array:
  * @a: (array) (element-type double) (transfer full): array of doubles to be converted into a #NcmVector.
@@ -206,7 +240,7 @@ ncm_vector_ref (NcmVector *cv)
 }
 
 /**
- * ncm_vector_copy:
+ * ncm_vector_dup:
  * @cv: a constant #NcmVector.
  *
  * This function copies the elements of the constant vector @cv into a new #NcmVector.
@@ -214,7 +248,7 @@ ncm_vector_ref (NcmVector *cv)
  * Returns: (transfer full): A #NcmVector.
    */
 NcmVector *
-ncm_vector_copy (const NcmVector *cv)
+ncm_vector_dup (const NcmVector *cv)
 {
   NcmVector *cv_cp = ncm_vector_new (ncm_vector_len(cv));
   gsl_vector_memcpy (ncm_vector_gsl(cv_cp), ncm_vector_const_gsl(cv));
@@ -232,7 +266,7 @@ ncm_vector_copy (const NcmVector *cv)
  * The new vector has @size elements.
  *
  * Returns: (transfer full): A #NcmVector.
-   */
+ */
 NcmVector *
 ncm_vector_get_subvector (NcmVector *cv, gsize k, gsize size)
 {
@@ -240,8 +274,7 @@ ncm_vector_get_subvector (NcmVector *cv, gsize k, gsize size)
 
   scv->vv = gsl_vector_subvector (ncm_vector_gsl (cv), k, size);
   scv->type = NCM_VECTOR_DERIVED;
-  scv->pobj = G_OBJECT (cv);
-  ncm_vector_ref (cv);
+  scv->pobj = G_OBJECT (ncm_vector_ref (cv));
 
   return scv;
 }
@@ -373,7 +406,7 @@ ncm_vector_get_subvector (NcmVector *cv, gsize k, gsize size)
  * @cv1: a #NcmVector.
  * @cv2: a #NcmVector.
  *
- * This function copies the components of the vector @cv1 into the vector @cv2.
+ * This function copies the components of the vector @cv2 into the vector @cv1.
  * The two vectors must have the same length.
  *
  */
@@ -443,17 +476,16 @@ static void
 _ncm_vector_dispose (GObject *object)
 {
   NcmVector *cv = NCM_VECTOR (object);
-  if (cv->a)
-  {
-	g_array_unref (cv->a);
-	cv->a = NULL;
-  }
 
-  if (cv->pobj)
+  if (cv->a != NULL)
   {
-	g_object_unref (cv->pobj);
-	cv->pobj = NULL;
+    g_array_unref (cv->a);
+    cv->a = NULL;
   }
+  
+  g_clear_object (&cv->pobj);
+
+  /* Chain up : end */
   G_OBJECT_CLASS (ncm_vector_parent_class)->dispose (object);
 }
 
@@ -496,10 +528,26 @@ void
 ncm_vector_free (NcmVector *cv)
 {
   if (g_object_is_floating (cv))
-	g_object_ref_sink (cv);
+    g_object_ref_sink (cv);
   g_object_unref (cv);
 }
 
+/**
+ * ncm_vector_clear:
+ * @cv: a #NcmVector.
+ *
+ * Atomically decrements the reference count of @cv by one. If the reference count drops to 0,
+ * all memory allocated by @cv is released. The pointer is set to NULL.
+ *
+ */
+void 
+ncm_vector_clear (NcmVector **cv)
+{
+  if (*cv != NULL && g_object_is_floating (*cv))
+    g_object_ref_sink (*cv);
+  g_clear_object (cv);  
+}
+
 /**
  * ncm_vector_const_free:
  * @cv: a constant #NcmVector.
@@ -515,14 +563,14 @@ ncm_vector_const_free (const NcmVector *cv)
 }
 
 static N_Vector
-_ncm_nvclone(N_Vector nv)
+_ncm_nvclone (N_Vector nv)
 {
-  NcmVector *v = ncm_vector_new (ncm_vector_len(NCM_N2VECTOR(nv)));
+  NcmVector *v = ncm_vector_new (ncm_vector_len (NCM_N2VECTOR (nv)));
   return ncm_vector_nvector (v);
 }
 
 static N_Vector
-_ncm_nvcloneempty(N_Vector nv)
+_ncm_nvcloneempty (N_Vector nv)
 {
   return ncm_vector_nvector (NULL);
 }
@@ -531,33 +579,35 @@ static void
 _ncm_nvspace(N_Vector nv, glong *lrw, glong *liw)
 {
   *lrw = ncm_vector_len(NCM_N2VECTOR(nv));
-  *liw = (sizeof(NcmVector) % 4 == 0) ? sizeof(NcmVector)/4 : sizeof(NcmVector)/4 + 1;
+  *liw = (sizeof (NcmVector) % 4 == 0) ? sizeof (NcmVector) / 4 : sizeof (NcmVector) / 4 + 1;
 }
 
 static realtype *
-_ncm_nvgetarraypointer(N_Vector nv)
+_ncm_nvgetarraypointer (N_Vector nv)
 {
   return NCM_VECTOR_DATA (NCM_N2VECTOR(nv));
 }
 
 static void
-_ncm_nvsetarraypointer(realtype *data, N_Vector nv)
+_ncm_nvsetarraypointer (realtype *data, N_Vector nv)
 {
-  NCM_VECTOR_DATA (NCM_N2VECTOR(nv)) = data;
+  NCM_VECTOR_DATA (NCM_N2VECTOR (nv)) = data;
 }
 
 static void
-_ncm_nvlinearsum(realtype a, N_Vector x, realtype b, N_Vector y, N_Vector z)
+_ncm_nvlinearsum (realtype a, N_Vector x, realtype b, N_Vector y, N_Vector z)
 {
 
 }
 
 static void
-_ncm_nvconst(realtype a, N_Vector nv)
+_ncm_nvconst (realtype a, N_Vector nv)
 {
   gsl_vector_set_all (ncm_vector_gsl(NCM_N2VECTOR(nv)), a);
 }
 
+static struct _generic_N_Vector_Ops _ncm_ops;
+
 /**
  * ncm_vector_nvector: (skip)
  * @cv: a #NcmVector.
@@ -572,18 +622,18 @@ ncm_vector_nvector (NcmVector *cv)
   struct _generic_N_Vector *nv = g_slice_new (struct _generic_N_Vector);
   g_object_ref_sink (cv);
   nv->content = cv;
-  nv->ops = NULL;
+  nv->ops = &_ncm_ops;
   return nv;
 }
 
 static void
 _ncm_vector_nvector_free (N_Vector nv)
 {
-  ncm_vector_free (NCM_N2VECTOR(nv));
+  ncm_vector_free (NCM_N2VECTOR (nv));
   g_slice_free (struct _generic_N_Vector, nv);
 }
 
-static const struct _generic_N_Vector_Ops _ncm_ops =
+static struct _generic_N_Vector_Ops _ncm_ops =
 {
   &_ncm_nvclone,
   &_ncm_nvcloneempty,
