@@ -29,7 +29,7 @@
 #include <glib-object.h>
 
 #include <numcosmo/math/ncm_model.h>
-#include <numcosmo/data/data.h>
+#include <numcosmo/math/ncm_data.h>
 #include <numcosmo/nc_distance.h>
 #include <numcosmo/math/ncm_mset_func.h>
 
@@ -43,9 +43,8 @@
 G_BEGIN_DECLS
 
 gulong ncm_random_seed (void);
-gsl_rng *ncm_get_rng (void);
 
-void ncm_finite_diff_calc_J (NcmModel *model, NcData *data, NcmMatrix *jac);
+void ncm_finite_diff_calc_J (NcmModel *model, NcmData *data, NcmMatrix *jac);
 
 gdouble *ncm_smoothd (gdouble *in, size_t N, size_t points, size_t pass);
 gboolean ncm_get_uniform_sample (NcmMSet *mset, NcmMSetFunc *func, gdouble x0, gdouble x1, NcmVector *sample);
@@ -74,6 +73,7 @@ gdouble ncm_numdiff_1 (gsl_function *F, const gdouble x, const gdouble ho, gdoub
 gdouble ncm_numdiff_2 (gsl_function *F, gdouble *ofx, const gdouble x, const gdouble ho, gdouble *err);
 gdouble ncm_numdiff_2_err (gsl_function *F, gdouble *ofx, const gdouble x, const gdouble ho, gdouble err, gdouble *ferr);
 gdouble ncm_sqrt1px_m1 (gdouble x);
+gint ncm_cmp (gdouble x, gdouble y, gdouble reltol);
 
 G_END_DECLS
 
