@@ -25,7 +25,10 @@
 #ifndef _NC_HICOSMO_QSPLINE_H_
 #define _NC_HICOSMO_QSPLINE_H_
 
+#include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/nc_hicosmo.h>
+#include <numcosmo/math/ncm_ode_spline.h>
 
 G_BEGIN_DECLS
 
@@ -63,7 +66,7 @@ typedef enum _NcHICosmoQSplineVParams
   NC_HICOSMO_QSPLINE_VPARAM_LEN, /*< skip >*/
 } NcHICosmoQSplineVParams;
 
-#define NC_HICOSMO_QSPLINE_DEFAULT_H0      NC_C_HUBBLE_CTE_WMAP
+#define NC_HICOSMO_QSPLINE_DEFAULT_H0      ncm_c_hubble_cte_wmap ()
 #define NC_HICOSMO_QSPLINE_DEFAULT_OMEGA_T ( 1.0)
 #define NC_HICOSMO_QSPLINE_DEFAULT_Q       (-0.5)
 #define NC_HICOSMO_QSPLINE_DEFAULT_Q_LEN      (6)
