@@ -8,11 +8,11 @@
 /*
  * numcosmo
  * Copyright (C) Mariana Penna Lima 2012 <pennalima@gmail.com>
- * numcosmo is free software: you can redistribute it and/or modify it
+   * numcosmo is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- *
+   *
  * numcosmo is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
@@ -40,6 +40,7 @@ void test_ncm_matrix_new_data_malloc (void);
 void test_ncm_matrix_new_data_static (void);
 void test_ncm_matrix_new_data_static_tda (void);
 void test_ncm_matrix_operations (void);
+void test_ncm_matrix_add_mul (void);
 void test_ncm_matrix_free (void);
 void test_ncm_matrix_submatrix (void);
 
@@ -58,6 +59,7 @@ main (gint argc, gchar *argv[])
   g_test_add_func ("/numcosmo/ncm_matrix/new_data_static", &test_ncm_matrix_new_data_static);
   g_test_add_func ("/numcosmo/ncm_matrix/new_data_static_tda", &test_ncm_matrix_new_data_static_tda);
   g_test_add_func ("/numcosmo/ncm_matrix/operations", &test_ncm_matrix_operations);
+  g_test_add_func ("/numcosmo/ncm_matrix/add_mul", &test_ncm_matrix_add_mul);
   g_test_add_func ("/numcosmo/ncm_matrix/submatrix", &test_ncm_matrix_submatrix);
   g_test_add_func ("/numcosmo/ncm_matrix/free", &test_ncm_matrix_free);
 
@@ -81,11 +83,11 @@ test_ncm_matrix_new_sanity (NcmMatrix *cm)
 
   for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
   {
-	const guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
-	const guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
-	const gdouble d = g_test_rand_double ();
-	ncm_matrix_set (cm, nr, nc, d);
-	g_assert (ncm_matrix_get (cm, nr, nc) == d);
+    const guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
+    const guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+    const gdouble d = g_test_rand_double ();
+    ncm_matrix_set (cm, nr, nc, d);
+    g_assert (ncm_matrix_get (cm, nr, nc) == d);
   }
 }
 
@@ -99,104 +101,104 @@ test_ncm_matrix_new (void)
 void
 test_ncm_matrix_operations (void)
 {
-  NcmMatrix *cm = ncm_matrix_copy (m);
+  NcmMatrix *cm = ncm_matrix_dup (m);
   guint i;
   test_ncm_matrix_new_sanity (cm);
 
   for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
   {
-	const guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
-	const guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
-	const gdouble d = g_test_rand_double ();
-	ncm_matrix_set (m, nr, nc, d);
-	g_assert (ncm_matrix_get (m, nr, nc) == d);
+    const guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
+    const guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+    const gdouble d = g_test_rand_double ();
+    ncm_matrix_set (m, nr, nc, d);
+    g_assert (ncm_matrix_get (m, nr, nc) == d);
   }
 
   for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
   {
-	guint nr, nc;
-	gdouble *d;
+    guint nr, nc;
+    gdouble *d;
 
-	nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
-	nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
-	d = ncm_matrix_ptr (m, nr, nc);
-	(*d) *= g_test_rand_double ();
+    nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
+    nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+    d = ncm_matrix_ptr (m, nr, nc);
+    (*d) *= g_test_rand_double ();
 
-	g_assert (ncm_matrix_get (m, nr, nc) == *d);
+    g_assert (ncm_matrix_get (m, nr, nc) == *d);
   }
 
   {
-	NcmMatrix *subm = ncm_matrix_get_submatrix (m, 3, 0, _NCM_MATRIX_TEST_NROW - 3, _NCM_MATRIX_TEST_NCOL);
-	NcmMatrix *sm_cp = ncm_matrix_copy (subm);
-	ncm_matrix_transpose (subm);
-	for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
-	{
-	  guint nr, nc;
-	  gdouble d;
+    NcmMatrix *subm = ncm_matrix_get_submatrix (m, 3, 0, _NCM_MATRIX_TEST_NROW - 3, _NCM_MATRIX_TEST_NCOL);
+    NcmMatrix *sm_cp = ncm_matrix_dup (subm);
+    ncm_matrix_transpose (subm);
+    for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
+    {
+      guint nr, nc;
+      gdouble d;
 
-	  nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 4);
-	  nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
-	  d = ncm_matrix_get (sm_cp, nr, nc);
+      nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 4);
+      nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+      d = ncm_matrix_get (sm_cp, nr, nc);
 
-	  g_assert (ncm_matrix_get (subm, nc, nr) == d);
-	}
-	ncm_matrix_free (sm_cp);
-	ncm_matrix_free (subm);
+      g_assert (ncm_matrix_get (subm, nc, nr) == d);
+    }
+    ncm_matrix_free (sm_cp);
+    ncm_matrix_free (subm);
   }
 
   for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
   {
-	guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
-	guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+    guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
+    guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
 
-	ncm_matrix_set_identity (m);
-	if (nr == nc)
-	  g_assert (ncm_matrix_get (m, nr, nc) == 1.0);
-	else
-	  g_assert (ncm_matrix_get (m, nr, nc) == 0.0);
+    ncm_matrix_set_identity (m);
+    if (nr == nc)
+      g_assert (ncm_matrix_get (m, nr, nc) == 1.0);
+    else
+      g_assert (ncm_matrix_get (m, nr, nc) == 0.0);
   }
 
   {
-	ncm_matrix_set_zero (m);
-	for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
-	{
-	  guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
-	  guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+    ncm_matrix_set_zero (m);
+    for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
+    {
+      guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
+      guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
 
-	  g_assert (ncm_matrix_get (m, nr, nc) == 0.0);
-	}
+      g_assert (ncm_matrix_get (m, nr, nc) == 0.0);
+    }
   }
 
   for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
   {
-	guint nr, nc;
-	gdouble d, d1 = g_test_rand_double ();
+    guint nr, nc;
+    gdouble d, d1 = g_test_rand_double ();
 
-	nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
-	nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
-	d = ncm_matrix_get (m, nr, nc);
-	ncm_matrix_scale (m, d1);
-	g_assert (ncm_matrix_get (m, nr, nc) == d * d1);
+    nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
+    nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+    d = ncm_matrix_get (m, nr, nc);
+    ncm_matrix_scale (m, d1);
+    g_assert (ncm_matrix_get (m, nr, nc) == d * d1);
   }
 
   {
-	NcmVector *v = ncm_vector_new (_NCM_MATRIX_TEST_NROW);
-	for (i = 0; i < _NCM_MATRIX_TEST_NROW; i++)
-	{
-	  ncm_vector_set (v, i, 8.2 + i);
-	}
-	guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
-	ncm_matrix_set_col (m, nc, v);
-	for (i = 0; i < _NCM_MATRIX_TEST_NROW; i++)
-	  g_assert (ncm_matrix_get (m, i, nc) == ncm_vector_get (v, i));
+    NcmVector *v = ncm_vector_new (_NCM_MATRIX_TEST_NROW);
+    for (i = 0; i < _NCM_MATRIX_TEST_NROW; i++)
+    {
+      ncm_vector_set (v, i, 8.2 + i);
+    }
+    guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+    ncm_matrix_set_col (m, nc, v);
+    for (i = 0; i < _NCM_MATRIX_TEST_NROW; i++)
+      g_assert (ncm_matrix_get (m, i, nc) == ncm_vector_get (v, i));
   }
 
   ncm_matrix_memcpy (m, cm);
   for (i = 0; i < _NCM_MATRIX_TEST_NROW; i++)
   {
-	guint j;
-	for (j = 0; j < _NCM_MATRIX_TEST_NCOL; j++)
-	  g_assert (ncm_matrix_get (m, i, j) == ncm_matrix_get (cm, i, j));
+    guint j;
+    for (j = 0; j < _NCM_MATRIX_TEST_NCOL; j++)
+      g_assert (ncm_matrix_get (m, i, j) == ncm_matrix_get (cm, i, j));
   }
 
 }
@@ -212,15 +214,15 @@ test_ncm_matrix_new_gsl (void)
   ncm_matrix_free (mm);
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	ncm_matrix_free (mm);
-	exit (0);
+    ncm_matrix_free (mm);
+    exit (0);
   }
   g_test_trap_assert_failed ();
 
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	g_assert (mm->gm == NULL);
-	exit (0);
+    g_assert (mm->gm == NULL);
+    exit (0);
   }
   g_test_trap_assert_passed ();
 }
@@ -243,15 +245,15 @@ test_ncm_matrix_new_array (void)
   ncm_matrix_free (mm);
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	ncm_matrix_free (mm);
-	exit (0);
+    ncm_matrix_free (mm);
+    exit (0);
   }
   g_test_trap_assert_failed ();
 
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	g_array_unref (mm->a);
-	exit (0);
+    g_array_unref (mm->a);
+    exit (0);
   }
   g_test_trap_assert_failed ();
 }
@@ -269,15 +271,15 @@ test_ncm_matrix_new_data_slice (void)
   ncm_matrix_free (mm);
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	ncm_matrix_free (mm);
-	exit (0);
+    ncm_matrix_free (mm);
+    exit (0);
   }
   g_test_trap_assert_failed ();
 
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	g_assert (NCM_MATRIX_DATA (mm) == NULL);
-	exit (0);
+    g_assert (NCM_MATRIX_DATA (mm) == NULL);
+    exit (0);
   }
   g_test_trap_assert_passed ();
 }
@@ -295,15 +297,15 @@ test_ncm_matrix_new_data_malloc (void)
   ncm_matrix_free (mm);
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	ncm_matrix_free (mm);
-	exit (0);
+    ncm_matrix_free (mm);
+    exit (0);
   }
   g_test_trap_assert_failed ();
 
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	g_assert (NCM_MATRIX_DATA (mm) == NULL);
-	exit (0);
+    g_assert (NCM_MATRIX_DATA (mm) == NULL);
+    exit (0);
   }
   g_test_trap_assert_passed ();
 }
@@ -320,8 +322,8 @@ test_ncm_matrix_new_data_static (void)
 
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	ncm_matrix_free (mm);
-	exit (0);
+    ncm_matrix_free (mm);
+    exit (0);
   }
   g_test_trap_assert_passed ();
 }
@@ -339,33 +341,33 @@ test_ncm_matrix_new_data_static_tda (void)
 
   for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
   {
-	const guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
-	const guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
-	const gdouble val = g_test_rand_double ();
-	ncm_matrix_set (mm, nr, nc, val);
-	g_assert (ncm_matrix_get (mm, nr, nc) == val);
+    const guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 1);
+    const guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 1);
+    const gdouble val = g_test_rand_double ();
+    ncm_matrix_set (mm, nr, nc, val);
+    g_assert (ncm_matrix_get (mm, nr, nc) == val);
   }
 
   {
-	NcmVector *v = ncm_matrix_get_col (mm, _NCM_MATRIX_TEST_NCOL - 1);
-	g_assert (ncm_vector_len (v) == NCM_MATRIX_NROWS (mm));
-	for (i = 0; i < _NCM_MATRIX_TEST_NROW; i++)
-	  g_assert (ncm_vector_get (v, i) == ncm_matrix_get (mm, i, _NCM_MATRIX_TEST_NCOL - 1));
-	ncm_vector_free (v);
+    NcmVector *v = ncm_matrix_get_col (mm, _NCM_MATRIX_TEST_NCOL - 1);
+    g_assert (ncm_vector_len (v) == NCM_MATRIX_NROWS (mm));
+    for (i = 0; i < _NCM_MATRIX_TEST_NROW; i++)
+      g_assert (ncm_vector_get (v, i) == ncm_matrix_get (mm, i, _NCM_MATRIX_TEST_NCOL - 1));
+    ncm_vector_free (v);
   }
 
   {
-	NcmVector *v = ncm_matrix_get_row (mm, _NCM_MATRIX_TEST_NROW - 1);
-	g_assert (ncm_vector_len (v) == NCM_MATRIX_NCOLS (mm));
-	for (i = 0; i < _NCM_MATRIX_TEST_NCOL; i++)
-	  g_assert (ncm_vector_get (v, i) == ncm_matrix_get (mm, _NCM_MATRIX_TEST_NROW - 1, i));
-	ncm_vector_free (v);
+    NcmVector *v = ncm_matrix_get_row (mm, _NCM_MATRIX_TEST_NROW - 1);
+    g_assert (ncm_vector_len (v) == NCM_MATRIX_NCOLS (mm));
+    for (i = 0; i < _NCM_MATRIX_TEST_NCOL; i++)
+      g_assert (ncm_vector_get (v, i) == ncm_matrix_get (mm, _NCM_MATRIX_TEST_NROW - 1, i));
+    ncm_vector_free (v);
   }
 
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	ncm_matrix_free (mm);
-	exit (0);
+    ncm_matrix_free (mm);
+    exit (0);
   }
   g_test_trap_assert_passed ();
 }
@@ -380,10 +382,10 @@ test_ncm_matrix_submatrix (void)
 
   while (ntests--)
   {
-	guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 5);
-	guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 3);
-	ncm_matrix_set (sm, nr, nc, g_test_rand_double ());
-	g_assert_cmpfloat (ncm_matrix_get (sm, nr, nc), ==, ncm_matrix_get (m, nr + 5, nc + 3));
+    guint nr = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NROW - 5);
+    guint nc = g_test_rand_int_range (0, _NCM_MATRIX_TEST_NCOL - 3);
+    ncm_matrix_set (sm, nr, nc, g_test_rand_double ());
+    g_assert_cmpfloat (ncm_matrix_get (sm, nr, nc), ==, ncm_matrix_get (m, nr + 5, nc + 3));
   }
 
   g_assert (NCM_IS_MATRIX (sm));
@@ -398,8 +400,88 @@ test_ncm_matrix_submatrix (void)
   ncm_matrix_free (sm);
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	ncm_matrix_free (sm);
-	exit (0);
+    ncm_matrix_free (sm);
+    exit (0);
+  }
+  g_test_trap_assert_failed ();
+}
+
+void
+test_ncm_matrix_add_mul (void)
+{
+  NcmMatrix *sm = ncm_matrix_get_submatrix (m, 5, 3, _NCM_MATRIX_TEST_NROW - 5, _NCM_MATRIX_TEST_NCOL - 3);
+  guint i, j;
+
+  g_assert (NCM_MATRIX_NROWS (sm) == (_NCM_MATRIX_TEST_NROW - 5) && NCM_MATRIX_NCOLS (sm) == (_NCM_MATRIX_TEST_NCOL - 3));
+
+  ncm_matrix_set_zero (sm);
+
+  for (i = 0; i < NCM_MATRIX_NROWS (sm); i++)
+  {
+    for (j = 0; j < NCM_MATRIX_NCOLS (sm); j++)
+    {
+      ncm_matrix_set (sm, i, j, g_test_rand_double ());
+      g_assert_cmpfloat (ncm_matrix_get (sm, i, j), ==, ncm_matrix_get (m, i + 5, j + 3));
+    }
+  }
+  
+  {
+    NcmMatrix *osm = ncm_matrix_dup (sm);
+    NcmMatrix *res = ncm_matrix_dup (sm);
+    const gdouble alpha = g_test_rand_double ();
+
+    for (i = 0; i < NCM_MATRIX_NROWS (osm); i++)
+    {
+      for (j = 0; j < NCM_MATRIX_NCOLS (osm); j++)
+      {
+        ncm_matrix_set (osm, i, j, g_test_rand_double ());
+      }
+    }
+    
+    ncm_matrix_add_mul (res, alpha, osm);
+
+    for (i = 0; i < NCM_MATRIX_NROWS (osm); i++)
+    {
+      for (j = 0; j < NCM_MATRIX_NCOLS (osm); j++)
+      {
+        g_assert_cmpfloat (ncm_matrix_get (res, i, j), ==, ncm_matrix_get (sm, i, j) + alpha * ncm_matrix_get (osm, i, j));
+      }
+    }
+
+    ncm_matrix_memcpy (res, osm);
+    
+    ncm_matrix_add_mul (res, alpha, sm);
+
+    for (i = 0; i < NCM_MATRIX_NROWS (sm); i++)
+    {
+      for (j = 0; j < NCM_MATRIX_NCOLS (sm); j++)
+      {
+        g_assert_cmpfloat (ncm_matrix_get (res, i, j), ==, ncm_matrix_get (osm, i, j) + alpha * ncm_matrix_get (sm, i, j));
+      }
+    }
+
+    ncm_matrix_free (osm);
+    if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
+    {
+      ncm_matrix_free (osm);
+      exit (0);
+    }
+    g_test_trap_assert_failed ();
+    
+    ncm_matrix_free (res);
+    if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
+    {
+      ncm_matrix_free (res);
+      exit (0);
+    }
+    g_test_trap_assert_failed ();
+  }
+
+  ncm_matrix_free (sm);
+  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
+  {
+    ncm_matrix_free (sm);
+    exit (0);
   }
   g_test_trap_assert_failed ();
 }
@@ -410,8 +492,8 @@ test_ncm_matrix_free (void)
   ncm_matrix_free (m);
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
   {
-	ncm_matrix_free (m);
-	exit (0);
+    ncm_matrix_free (m);
+    exit (0);
   }
   g_test_trap_assert_failed ();
 }
